@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
+/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -18,6 +18,7 @@
 #define ACL_MANAGER_H_
 
 #include "AuthManager.h"
+#include "AuthRequest.h"
 #include "PoolObjectSQL.h"
 #include "AclRule.h"
 
@@ -27,27 +28,35 @@ using namespace std;
 
 class PoolObjectAuth;
 
+extern "C" void * acl_action_loop(void *arg);
+
 /**
  *  This class manages the ACL rules and the authorization engine
  */
-class AclManager : public Callbackable
+class AclManager : public Callbackable, public ActionListener
 {
 public:
-    AclManager(SqlDB * _db);
 
-    AclManager():db(0),lastOID(0)
-    {
-       pthread_mutex_init(&mutex, 0);
-    };
+    /**
+     *  @param _db pointer to the DB
+     *  @param zone_id of the Zone
+     *  @param is_federation_slave true is this oned is a federation slave. If
+     *  it is true, it will reload periodically rules from the DB
+     *  @param timer_period period to reload the rules
+     */
+    AclManager(SqlDB * _db, int zone_id, bool is_federation_slave, time_t timer);
 
     virtual ~AclManager();
 
     /**
-     *  Loads the ACL rule set from the DB
+     *  Loads the ACL rule set from the DB, and starts the refresh loop is
+     *  refresh_cache is set
      *    @return 0 on success.
      */
     int start();
 
+    void finalize();
+
     /* ---------------------------------------------------------------------- */
     /* Rule management                                                        */
     /* ---------------------------------------------------------------------- */
@@ -57,13 +66,13 @@ public:
      *  authorizes the operation.
      *
      *    @param uid The user ID requesting to be authorized
-     *    @param gid Group ID of the user
+     *    @param user_groups Set of group IDs that the user is part of
      *    @param obj_perms The object's permission attributes
      *    @param op The operation to be authorized
      *    @return true if the authorization is granted by any rule
      */
     const bool authorize(int                    uid,
-                         int                    gid,
+                         const set<int>&        user_groups,
                          const PoolObjectAuth&  obj_perms,
                          AuthRequest::Operation op);
 
@@ -73,6 +82,7 @@ public:
      *    @param user 64 bit ID and flags
      *    @param resource 64 bit ID and flags
      *    @param rights 64 bit flags
+     *    @param zone 64 bit flags
      *    @param error_str Returns the error reason, if any
      *
      *    @return the oid assigned to the rule on success,
@@ -80,9 +90,10 @@ public:
      *    -2 if the rule is malformed,
      *    -3 if the DB insert failed
      */
-    virtual int add_rule(long long user, 
-                         long long resource, 
+    virtual int add_rule(long long user,
+                         long long resource,
                          long long rights,
+                         long long zone,
                          string&   error_str);
     /**
      *  Deletes a rule from the ACL rule set
@@ -93,6 +104,23 @@ public:
      */
     virtual int del_rule(int oid, string& error_str);
 
+    /**
+     *  Deletes a new rule from the ACL rule set
+     *
+     *    @param user 64 bit ID and flags
+     *    @param resource 64 bit ID and flags
+     *    @param rights 64 bit flags
+     *    @param zone 64 bit flags
+     *
+     *    @param error_str Returns the error reason, if any
+     *    @return 0 on success
+     */
+    virtual int del_rule(long long user,
+                         long long resource,
+                         long long rights,
+                         long long zone,
+                         string&   error_str);
+
     /**
      * Deletes rules that apply to this user id
      *
@@ -107,6 +135,20 @@ public:
      */
     void del_gid_rules(int gid);
 
+    /**
+     * Deletes rules that apply to this cluster id
+     *
+     * @param cid The cluster id
+     */
+    void del_cid_rules(int cid);
+
+    /**
+     * Deletes rules that apply to this cluster id
+     *
+     * @param zid The zone id
+     */
+    void del_zid_rules(int zid);
+
     /**
      * Deletes all rules that apply to this resource
      *
@@ -120,20 +162,22 @@ public:
      * the given user to perform the operation.
      *
      *    @param uid The user ID
-     *    @param gid Group ID of the user
+     *    @param user_groups Set of group IDs that the user is part of
      *    @param obj_type The object over which the search will be performed
      *    @param op The operation to be searched
      *    @param all True if the user can perform the operation over any object
      *    @param oids Set of object IDs over which the user can operate
      *    @param gids Set of object group IDs over which the user can operate
+     *    @param cids Set of object cluster IDs over which the user can operate
      */
     void reverse_search(int                       uid,
-                        int                       gid,
+                        const set<int>&           user_groups,
                         PoolObjectSQL::ObjectType obj_type,
                         AuthRequest::Operation    op,
                         bool&                     all,
                         vector<int>&              oids,
-                        vector<int>&              gids);
+                        vector<int>&              gids,
+                        vector<int>&              cids);
 
     /* ---------------------------------------------------------------------- */
     /* DB management                                                          */
@@ -152,8 +196,33 @@ public:
      */
     virtual int dump(ostringstream& oss);
 
+    // ----------------------------------------
+    // Refresh loop thread
+    // ----------------------------------------
+
+    /**
+     *  Gets the AclManager thread identification. The thread is only
+     *  initialized if the refresh_cache flag is true.
+     *    @return pthread_t for the manager thread (that in the action loop).
+     */
+    pthread_t get_thread_id() const
+    {
+        return acl_thread;
+    };
+
 protected:
 
+    /**
+     *  Constructor for derived ACL managers. Classes derived from this one
+     *  will operate in a stand-alone fashion (i.e. no refresh of ACL rules
+     *  from DB)
+     */
+    AclManager(int _zone_id)
+        :zone_id(_zone_id), db(0),lastOID(0), is_federation_slave(false)
+    {
+       pthread_mutex_init(&mutex, 0);
+    };
+
     // ----------------------------------------
     // ACL rules management
     // ----------------------------------------
@@ -178,10 +247,12 @@ private:
      *    @param user_req user/group id and flags
      *    @param resource_oid_req 64 bit request, ob. type and individual oid
      *    @param resource_gid_req 64 bit request, ob. type and group id
+     *    @param resource_cid_req 64 bit request, ob. type and cluster id
      *    @param resource_all_req 64 bit request, ob. type and all flag
      *    @param rights_req Requested rights
      *    @param individual_obj_type Mask with ob. type and individual flags
      *    @param group_obj_type Mask with ob. type and group flags
+     *    @param cluster_obj_type Mask with ob. type and cluster flags
      *    @param rules ACL rules to match
      *
      *    @return true if any rule grants permission
@@ -190,10 +261,12 @@ private:
             long long user_req,
             long long resource_oid_req,
             long long resource_gid_req,
+            long long resource_cid_req,
             long long resource_all_req,
             long long rights_req,
             long long individual_obj_type,
             long long group_obj_type,
+            long long cluster_obj_type,
             multimap<long long, AclRule*> &rules);
 
     /**
@@ -203,10 +276,12 @@ private:
      *    @param user_req user/group id and flags
      *    @param resource_oid_req 64 bit request, ob. type and individual oid
      *    @param resource_gid_req 64 bit request, ob. type and group id
+     *    @param resource_cid_req 64 bit request, ob. type and cluster id
      *    @param resource_all_req 64 bit request, ob. type and all flag
      *    @param rights_req Requested rights
      *    @param individual_obj_type Mask with ob. type and individual flags
      *    @param group_obj_type Mask with ob. type and group flags
+     *    @param cluster_obj_type Mask with ob. type and cluster flags
      *    @param tmp_rules Temporary map group of ACL rules
      *
      *    @return true if any rule grants permission
@@ -215,10 +290,12 @@ private:
             long long user_req,
             long long resource_oid_req,
             long long resource_gid_req,
+            long long resource_cid_req,
             long long resource_all_req,
             long long rights_req,
             long long individual_obj_type,
             long long group_obj_type,
+            long long cluster_obj_type,
             multimap<long long, AclRule*> &tmp_rules);
 
     /**
@@ -238,6 +315,19 @@ private:
             long long resource_req,
             long long resource_mask);
 
+    /**
+     * Deletes all rules that match the zone mask
+     *
+     * @param zone_req Mask to match
+     */
+    void del_zone_matching_rules(long long zone_req);
+
+    // ----------------------------------------
+    // Local zone
+    // ----------------------------------------
+
+    int zone_id;
+
     // ----------------------------------------
     // Mutex synchronization
     // ----------------------------------------
@@ -335,6 +425,45 @@ private:
      *  Callback to set the lastOID
      */
     int  init_cb(void *nil, int num, char **values, char **names);
+
+    // ----------------------------------------
+    // Refresh loop thread
+    // ----------------------------------------
+
+    /**
+     * Flag to refresh the cache periodically
+     */
+    bool            is_federation_slave;
+
+    /**
+     *  Timer period for the cache refresh loop.
+     */
+    time_t          timer_period;
+
+    /**
+     *  Thread id for the ACL Manager
+     */
+    pthread_t       acl_thread;
+
+    /**
+     *  Action engine for the Manager
+     */
+    ActionManager   am;
+
+    /**
+     *  Function to execute the Manager action loop method within a new pthread
+     *  (requires C linkage)
+     */
+    friend void * acl_action_loop(void *arg);
+
+    /**
+     *  The action function executed when an action is triggered.
+     *    @param action the name of the action
+     *    @param arg arguments for the action function
+     */
+    void do_action(
+        const string &  action,
+        void *          arg);
 };
 
 #endif /*ACL_MANAGER_H*/
