@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
+/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -29,6 +29,8 @@ class ImageTemplate : public Template
 public:
     ImageTemplate() : Template(true,'=',"TEMPLATE"){};
 
+    ImageTemplate(const ImageTemplate& tmpl):Template(tmpl){};
+
     ~ImageTemplate(){};
 
     /**
@@ -50,6 +52,15 @@ public:
         return (saving.empty() == false);
     }
 
+    bool is_saving_hot()
+    {
+        string save_as_hot;
+
+        get(saving_hot_attribute, save_as_hot);
+
+        return (save_as_hot.empty() == false);
+    }
+
     void set_saving()
     {
         SingleAttribute * attr= new SingleAttribute(saving_attribute, "YES");
@@ -59,6 +70,15 @@ public:
         set(attr);
     }
 
+    void set_saving_hot()
+    {
+        SingleAttribute * attr = new SingleAttribute(saving_hot_attribute,"YES");
+
+        erase(saving_hot_attribute);
+
+        set(attr);
+    }
+
     void unset_saving()
     {
         erase(saving_attribute);
@@ -70,6 +90,7 @@ private:
     static vector<string> restricted_attributes;
 
     static string saving_attribute;
+    static string saving_hot_attribute;
 
     /**
      * Stores the attributes as restricted, these attributes will be used in
@@ -81,7 +102,7 @@ private:
         Template::set_restricted_attributes(rattrs, restricted_attributes);
     };
 };
-    
+
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
