@@ -53,7 +53,8 @@ public:
         CANCEL_FAILURE,   /**< Sent by the VMM when a cancel action fails     */
         MONITOR_FAILURE,  /**< Sent by the VMM when a VM has failed while active */
         MONITOR_SUSPEND,  /**< Sent by the VMM when a VM is paused while active */
-        MONITOR_DONE,     /**< Sent by the VMM when a VM is not found */
+        MONITOR_DONE,     /**< Sent by the VMM when a Host cannot be monitored*/
+        MONITOR_POWEROFF, /**< Sent by the VMM when a VM is not found */
         PROLOG_SUCCESS,   /**< Sent by the TM when the prolog phase succeeds  */
         PROLOG_FAILURE,   /**< Sent by the TM when the prolog phase fails     */
         EPILOG_SUCCESS,   /**< Sent by the TM when the epilog phase succeeds  */
@@ -197,6 +198,8 @@ private:
 
     void monitor_done_action(int vid);
 
+    void monitor_poweroff_action(int vid);
+
     void prolog_success_action(int vid);
 
     void prolog_failure_action(int vid);
