@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
+/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -42,8 +42,22 @@ class RequestManager : public ActionListener
 {
 public:
 
-    RequestManager(int _port, const string _xml_log_file)
-            :port(_port), socket_fd(-1), xml_log_file(_xml_log_file)
+    RequestManager(
+            int _port,
+            int _max_conn,
+            int _max_conn_backlog,
+            int _keepalive_timeout,
+            int _keepalive_max_conn,
+            int _timeout,
+            const string _xml_log_file):
+                port(_port),
+                socket_fd(-1),
+                max_conn(_max_conn),
+                max_conn_backlog(_max_conn_backlog),
+                keepalive_timeout(_keepalive_timeout),
+                keepalive_max_conn(_keepalive_max_conn),
+                timeout(_timeout),
+                xml_log_file(_xml_log_file)
     {
         am.addListener(this);
     };
@@ -106,6 +120,31 @@ private:
      */
     int socket_fd;
 
+    /**
+     *  Max connections
+     */
+    int max_conn;
+
+    /*
+     *  Max backlog connections
+     */
+    int max_conn_backlog;
+
+    /*
+     *  Keepalive timeout
+     */
+    int keepalive_timeout;
+
+    /*
+     *  Keepalive max conn
+     */
+    int keepalive_max_conn;
+
+    /*
+     *  Timeout
+     */
+    int timeout;
+
     /**
      *  Filename for the log of the xmlrpc server that listens
      */
