@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
+/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -52,6 +52,25 @@ protected:
 
     virtual void request_execute(xmlrpc_c::paramList const& _paramList,
                                  RequestAttributes& att);
+
+    PoolObjectSQL * get_and_quota(int                       oid,
+                                  int                       new_uid,
+                                  int                       new_gid,
+                                  RequestAttributes&        att);
+
+    /**
+     * Checks if the new owner cannot has other object with the same name (if
+     * the pool does not allow it)
+     *
+     * @param oid Object id
+     * @param noid New owner user id
+     * @param att the specific request attributes
+     *
+     * @return 0 if the operation is allowed, -1 otherwise
+     */
+    virtual int check_name_unique(int oid, int noid, RequestAttributes& att);
+
+    virtual PoolObjectSQL * get(const string& name, int uid, bool lock) = 0;
 };
 
 /* ------------------------------------------------------------------------- */
@@ -70,6 +89,16 @@ public:
     };
 
     ~VirtualMachineChown(){};
+
+    int check_name_unique(int oid, int noid, RequestAttributes& att)
+    {
+        return 0;
+    };
+
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return 0;
+    };
 };
 
 /* ------------------------------------------------------------------------- */
@@ -81,13 +110,18 @@ public:
     TemplateChown():
         RequestManagerChown("TemplateChown",
                             "Changes ownership of a virtual machine template")
-    {    
+    {
         Nebula& nd  = Nebula::instance();
         pool        = nd.get_tpool();
         auth_object = PoolObjectSQL::TEMPLATE;
     };
 
     ~TemplateChown(){};
+
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return static_cast<VMTemplatePool*>(pool)->get(name, uid, lock);
+    };
 };
 
 /* ------------------------------------------------------------------------- */
@@ -108,6 +142,10 @@ public:
 
     ~VirtualNetworkChown(){};
 
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return static_cast<VirtualNetworkPool*>(pool)->get(name, uid, lock);
+    };
 };
 
 /* ------------------------------------------------------------------------- */
@@ -127,6 +165,10 @@ public:
 
     ~ImageChown(){};
 
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return static_cast<ImagePool*>(pool)->get(name, uid, lock);
+    };
 };
 
 /* ------------------------------------------------------------------------- */
@@ -151,6 +193,11 @@ public:
 
     virtual void request_execute(xmlrpc_c::paramList const& _paramList,
                                  RequestAttributes& att);
+
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return 0;
+    };
 };
 
 /* ------------------------------------------------------------------------- */
@@ -170,6 +217,33 @@ public:
 
     ~DatastoreChown(){};
 
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return 0;
+    };
+};
+
+/* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------------------- */
+
+class DocumentChown : public RequestManagerChown
+{
+public:
+    DocumentChown():
+        RequestManagerChown("DocumentChown",
+                            "Changes ownership of a generic document")
+    {
+        Nebula& nd  = Nebula::instance();
+        pool        = nd.get_docpool();
+        auth_object = PoolObjectSQL::DOCUMENT;
+    };
+
+    ~DocumentChown(){};
+
+    PoolObjectSQL * get(const string& name, int uid, bool lock)
+    {
+        return 0;
+    };
 };
 
 /* -------------------------------------------------------------------------- */
