@@ -37,6 +37,7 @@ public:
         HostPool *                _hpool,
         time_t                    _timer_period,
         time_t                    _poll_period,
+        bool                      _do_vm_poll,
         int                       _vm_limit,
         vector<const Attribute*>& _mads);
 
@@ -131,6 +132,11 @@ private:
      */
     time_t                  poll_period;
 
+    /**
+     *  Perform pro-active VM monitoring
+     */
+    bool                    do_vm_poll;
+
     /**
      *  Virtual Machine polling limit
      */
