@@ -29,7 +29,7 @@
 usage() {
  echo
  echo "Usage: install.sh [-u install_user] [-g install_group] [-k keep conf]"
- echo "                  [-d ONE_LOCATION] [-c occi|ec2] [-r] [-h]"
+ echo "                  [-d ONE_LOCATION] [-c cli|ec2] [-r] [-h]"
  echo
  echo "-u: user that will run opennebula, defaults to user executing install.sh"
  echo "-g: group of the user that will run opennebula, defaults to user"
@@ -39,7 +39,7 @@ usage() {
  echo "    OpenNebula for the first time"
  echo "-d: target installation directory, if not defined it'd be root. Must be"
  echo "    an absolute path."
- echo "-c: install client utilities: OpenNebula cli, occi and ec2 client files"
+ echo "-c: install client utilities: OpenNebula cli and ec2 client files"
  echo "-s: install OpenNebula Sunstone"
  echo "-G: install OpenNebula Gate"
  echo "-f: install OpenNebula Flow"
@@ -214,7 +214,6 @@ ETC_DIRS="$ETC_LOCATION/vmm_exec \
           $ETC_LOCATION/auth \
           $ETC_LOCATION/auth/certificates \
           $ETC_LOCATION/ec2query_templates \
-          $ETC_LOCATION/occi_templates \
           $ETC_LOCATION/sunstone-views \
           $ETC_LOCATION/cli"
 
@@ -223,7 +222,6 @@ LIB_DIRS="$LIB_LOCATION/ruby \
           $LIB_LOCATION/ruby/cloud/ \
           $LIB_LOCATION/ruby/cloud/econe \
           $LIB_LOCATION/ruby/cloud/econe/views \
-          $LIB_LOCATION/ruby/cloud/occi \
           $LIB_LOCATION/ruby/cloud/marketplace \
           $LIB_LOCATION/ruby/cloud/CloudAuth \
           $LIB_LOCATION/ruby/onedb \
@@ -250,12 +248,16 @@ VAR_DIRS="$VAR_LOCATION/remotes \
           $VAR_LOCATION/remotes/im/xen4-probes.d \
           $VAR_LOCATION/remotes/im/vmware.d \
           $VAR_LOCATION/remotes/im/ec2.d \
+          $VAR_LOCATION/remotes/im/sl.d \
+          $VAR_LOCATION/remotes/im/az.d \
           $VAR_LOCATION/remotes/vmm \
           $VAR_LOCATION/remotes/vmm/kvm \
           $VAR_LOCATION/remotes/vmm/xen3 \
           $VAR_LOCATION/remotes/vmm/xen4 \
           $VAR_LOCATION/remotes/vmm/vmware \
           $VAR_LOCATION/remotes/vmm/ec2 \
+          $VAR_LOCATION/remotes/vmm/sl \
+          $VAR_LOCATION/remotes/vmm/az \
           $VAR_LOCATION/remotes/vnm \
           $VAR_LOCATION/remotes/vnm/802.1Q \
           $VAR_LOCATION/remotes/vnm/dummy \
@@ -273,6 +275,7 @@ VAR_DIRS="$VAR_LOCATION/remotes \
           $VAR_LOCATION/remotes/tm/vmfs \
           $VAR_LOCATION/remotes/tm/lvm \
           $VAR_LOCATION/remotes/tm/ceph \
+          $VAR_LOCATION/remotes/tm/dev \
           $VAR_LOCATION/remotes/hooks \
           $VAR_LOCATION/remotes/hooks/ft \
           $VAR_LOCATION/remotes/datastore \
@@ -281,6 +284,7 @@ VAR_DIRS="$VAR_LOCATION/remotes \
           $VAR_LOCATION/remotes/datastore/vmfs \
           $VAR_LOCATION/remotes/datastore/lvm \
           $VAR_LOCATION/remotes/datastore/ceph \
+          $VAR_LOCATION/remotes/datastore/dev \
           $VAR_LOCATION/remotes/auth \
           $VAR_LOCATION/remotes/auth/plain \
           $VAR_LOCATION/remotes/auth/ssh \
@@ -338,6 +342,7 @@ SUNSTONE_DIRS="$SUNSTONE_LOCATION/routes \
                $SUNSTONE_LOCATION/public/vendor/4.0/jdpicker_1.1 \
                $SUNSTONE_LOCATION/public/vendor/4.0/jdpicker_1.1/images \
                $SUNSTONE_LOCATION/public/images \
+               $SUNSTONE_LOCATION/public/images/logos \
                $SUNSTONE_LOCATION/views"
 
 ONEFLOW_DIRS="$ONEFLOW_LOCATION/lib \
@@ -349,10 +354,6 @@ LIB_ECO_CLIENT_DIRS="$LIB_LOCATION/ruby \
                  $LIB_LOCATION/ruby/cloud/ \
                  $LIB_LOCATION/ruby/cloud/econe"
 
-LIB_OCCI_CLIENT_DIRS="$LIB_LOCATION/ruby \
-                 $LIB_LOCATION/ruby/opennebula \
-                 $LIB_LOCATION/ruby/cloud/occi"
-
 LIB_MARKET_CLIENT_DIRS="$LIB_LOCATION/ruby \
                  $LIB_LOCATION/ruby/opennebula \
                  $LIB_LOCATION/ruby/cloud/marketplace"
@@ -366,7 +367,7 @@ LIB_CLI_CLIENT_DIRS="$LIB_LOCATION/ruby/cli \
 CONF_CLI_DIRS="$ETC_LOCATION/cli"
 
 if [ "$CLIENT" = "yes" ]; then
-    MAKE_DIRS="$MAKE_DIRS $LIB_ECO_CLIENT_DIRS $LIB_OCCI_CLIENT_DIRS $LIB_MARKET_CLIENT_DIRS \
+    MAKE_DIRS="$MAKE_DIRS $LIB_ECO_CLIENT_DIRS $LIB_MARKET_CLIENT_DIRS \
                $LIB_OCA_CLIENT_DIRS $LIB_CLI_CLIENT_DIRS $CONF_CLI_DIRS \
                $ETC_LOCATION"
 elif [ "$ONEGATE" = "yes" ]; then
@@ -409,6 +410,8 @@ INSTALL_FILES=(
     IM_PROBES_XEN4_PROBES_FILES:$VAR_LOCATION/remotes/im/xen4-probes.d
     IM_PROBES_VMWARE_FILES:$VAR_LOCATION/remotes/im/vmware.d
     IM_PROBES_EC2_FILES:$VAR_LOCATION/remotes/im/ec2.d
+    IM_PROBES_SL_FILES:$VAR_LOCATION/remotes/im/sl.d
+    IM_PROBES_AZ_FILES:$VAR_LOCATION/remotes/im/az.d
     IM_PROBES_VERSION:$VAR_LOCATION/remotes
     AUTH_SSH_FILES:$VAR_LOCATION/remotes/auth/ssh
     AUTH_X509_FILES:$VAR_LOCATION/remotes/auth/x509
@@ -422,6 +425,8 @@ INSTALL_FILES=(
     VMM_EXEC_XEN4_SCRIPTS:$VAR_LOCATION/remotes/vmm/xen4
     VMM_EXEC_VMWARE_SCRIPTS:$VAR_LOCATION/remotes/vmm/vmware
     VMM_EXEC_EC2_SCRIPTS:$VAR_LOCATION/remotes/vmm/ec2
+    VMM_EXEC_SL_SCRIPTS:$VAR_LOCATION/remotes/vmm/sl
+    VMM_EXEC_AZ_SCRIPTS:$VAR_LOCATION/remotes/vmm/az
     TM_FILES:$VAR_LOCATION/remotes/tm
     TM_SHARED_FILES:$VAR_LOCATION/remotes/tm/shared
     TM_FS_LVM_FILES:$VAR_LOCATION/remotes/tm/fs_lvm
@@ -430,6 +435,7 @@ INSTALL_FILES=(
     TM_VMFS_FILES:$VAR_LOCATION/remotes/tm/vmfs
     TM_LVM_FILES:$VAR_LOCATION/remotes/tm/lvm
     TM_CEPH_FILES:$VAR_LOCATION/remotes/tm/ceph
+    TM_DEV_FILES:$VAR_LOCATION/remotes/tm/dev
     TM_DUMMY_FILES:$VAR_LOCATION/remotes/tm/dummy
     DATASTORE_DRIVER_COMMON_SCRIPTS:$VAR_LOCATION/remotes/datastore/
     DATASTORE_DRIVER_DUMMY_SCRIPTS:$VAR_LOCATION/remotes/datastore/dummy
@@ -437,6 +443,7 @@ INSTALL_FILES=(
     DATASTORE_DRIVER_VMFS_SCRIPTS:$VAR_LOCATION/remotes/datastore/vmfs
     DATASTORE_DRIVER_LVM_SCRIPTS:$VAR_LOCATION/remotes/datastore/lvm
     DATASTORE_DRIVER_CEPH_SCRIPTS:$VAR_LOCATION/remotes/datastore/ceph
+    DATASTORE_DRIVER_DEV_SCRIPTS:$VAR_LOCATION/remotes/datastore/dev
     NETWORK_FILES:$VAR_LOCATION/remotes/vnm
     NETWORK_8021Q_FILES:$VAR_LOCATION/remotes/vnm/802.1Q
     NETWORK_DUMMY_FILES:$VAR_LOCATION/remotes/vnm/dummy
@@ -454,8 +461,6 @@ INSTALL_FILES=(
     ECO_LIB_FILES:$LIB_LOCATION/ruby/cloud/econe
     ECO_LIB_VIEW_FILES:$LIB_LOCATION/ruby/cloud/econe/views
     ECO_BIN_FILES:$BIN_LOCATION
-    OCCI_LIB_FILES:$LIB_LOCATION/ruby/cloud/occi
-    OCCI_BIN_FILES:$BIN_LOCATION
     MARKET_LIB_FILES:$LIB_LOCATION/ruby/cloud/marketplace
     MARKET_BIN_FILES:$BIN_LOCATION
     MAN_FILES:$MAN_LOCATION
@@ -473,8 +478,6 @@ INSTALL_CLIENT_FILES=(
     ECO_LIB_CLIENT_FILES:$LIB_LOCATION/ruby/cloud/econe
     ECO_BIN_CLIENT_FILES:$BIN_LOCATION
     COMMON_CLOUD_CLIENT_LIB_FILES:$LIB_LOCATION/ruby/cloud
-    OCCI_LIB_CLIENT_FILES:$LIB_LOCATION/ruby/cloud/occi
-    OCCI_BIN_CLIENT_FILES:$BIN_LOCATION
     MARKET_LIB_CLIENT_FILES:$LIB_LOCATION/ruby/cloud/marketplace
     MARKET_BIN_CLIENT_FILES:$BIN_LOCATION
     CLI_BIN_FILES:$BIN_LOCATION
@@ -520,6 +523,7 @@ INSTALL_SUNSTONE_FILES=(
     SUNSTONE_PUBLIC_NEW_VENDOR_JDPICKER:$SUNSTONE_LOCATION/public/vendor/4.0/jdpicker_1.1
     SUNSTONE_PUBLIC_NEW_VENDOR_JDPICKER_IMAGES:$SUNSTONE_LOCATION/public/vendor/4.0/jdpicker_1.1/images
     SUNSTONE_PUBLIC_IMAGES_FILES:$SUNSTONE_LOCATION/public/images
+    SUNSTONE_PUBLIC_LOGOS_FILES:$SUNSTONE_LOCATION/public/images/logos
     SUNSTONE_PUBLIC_LOCALE_CA:$SUNSTONE_LOCATION/public/locale/ca
     SUNSTONE_PUBLIC_LOCALE_CS_CZ:$SUNSTONE_LOCATION/public/locale/cs_CZ
     SUNSTONE_PUBLIC_LOCALE_DE:$SUNSTONE_LOCATION/public/locale/de
@@ -570,13 +574,13 @@ INSTALL_ETC_FILES=(
     ETC_FILES:$ETC_LOCATION
     VMWARE_ETC_FILES:$ETC_LOCATION
     EC2_ETC_FILES:$ETC_LOCATION
+    SL_ETC_FILES:$ETC_LOCATION
+    AZ_ETC_FILES:$ETC_LOCATION
     VMM_EXEC_ETC_FILES:$ETC_LOCATION/vmm_exec
     HM_ETC_FILES:$ETC_LOCATION/hm
     AUTH_ETC_FILES:$ETC_LOCATION/auth
     ECO_ETC_FILES:$ETC_LOCATION
     ECO_ETC_TEMPLATE_FILES:$ETC_LOCATION/ec2query_templates
-    OCCI_ETC_FILES:$ETC_LOCATION
-    OCCI_ETC_TEMPLATE_FILES:$ETC_LOCATION/occi_templates
     CLI_CONF_FILES:$ETC_LOCATION/cli
 )
 
@@ -782,6 +786,50 @@ VMM_EXEC_EC2_SCRIPTS="src/vmm_mad/remotes/ec2/cancel \
                       src/vmm_mad/remotes/ec2/shutdown \
                       src/vmm_mad/remotes/ec2/ec2_driver.rb"
 
+#------------------------------------------------------------------------------
+# VMM Driver SoftLayer scripts, to be installed under $REMOTES_LOCATION/vmm/sl
+#------------------------------------------------------------------------------
+
+VMM_EXEC_SL_SCRIPTS="src/vmm_mad/remotes/sl/cancel \
+                     src/vmm_mad/remotes/sl/attach_disk \
+                     src/vmm_mad/remotes/sl/detach_disk \
+                     src/vmm_mad/remotes/sl/attach_nic \
+                     src/vmm_mad/remotes/sl/detach_nic \
+                     src/vmm_mad/remotes/sl/snapshot_create \
+                     src/vmm_mad/remotes/sl/snapshot_revert \
+                     src/vmm_mad/remotes/sl/snapshot_delete \
+                     src/vmm_mad/remotes/sl/deploy \
+                     src/vmm_mad/remotes/sl/migrate \
+                     src/vmm_mad/remotes/sl/restore \
+                     src/vmm_mad/remotes/sl/reboot \
+                     src/vmm_mad/remotes/sl/reset \
+                     src/vmm_mad/remotes/sl/save \
+                     src/vmm_mad/remotes/sl/poll \
+                     src/vmm_mad/remotes/sl/shutdown \
+                     src/vmm_mad/remotes/sl/sl_driver.rb"
+
+#------------------------------------------------------------------------------
+# VMM Driver Azure scripts, to be installed under $REMOTES_LOCATION/vmm/az
+#------------------------------------------------------------------------------
+
+VMM_EXEC_AZ_SCRIPTS="src/vmm_mad/remotes/az/cancel \
+                     src/vmm_mad/remotes/az/attach_disk \
+                     src/vmm_mad/remotes/az/detach_disk \
+                     src/vmm_mad/remotes/az/attach_nic \
+                     src/vmm_mad/remotes/az/detach_nic \
+                     src/vmm_mad/remotes/az/snapshot_create \
+                     src/vmm_mad/remotes/az/snapshot_revert \
+                     src/vmm_mad/remotes/az/snapshot_delete \
+                     src/vmm_mad/remotes/az/deploy \
+                     src/vmm_mad/remotes/az/migrate \
+                     src/vmm_mad/remotes/az/restore \
+                     src/vmm_mad/remotes/az/reboot \
+                     src/vmm_mad/remotes/az/reset \
+                     src/vmm_mad/remotes/az/save \
+                     src/vmm_mad/remotes/az/poll \
+                     src/vmm_mad/remotes/az/shutdown \
+                     src/vmm_mad/remotes/az/az_driver.rb"
+
 #-------------------------------------------------------------------------------
 # Information Manager Probes, to be installed under $REMOTES_LOCATION/im
 #-------------------------------------------------------------------------------
@@ -829,6 +877,9 @@ IM_PROBES_VMWARE_FILES="src/im_mad/remotes/vmware.d/vmware.rb"
 
 IM_PROBES_EC2_FILES="src/im_mad/remotes/ec2.d/poll"
 
+IM_PROBES_SL_FILES="src/im_mad/remotes/sl.d/poll"
+IM_PROBES_AZ_FILES="src/im_mad/remotes/az.d/poll"
+
 IM_PROBES_VERSION="src/im_mad/remotes/VERSION"
 
 #-------------------------------------------------------------------------------
@@ -854,6 +905,7 @@ AUTH_PLAIN_FILES="src/authm_mad/remotes/plain/authenticate"
 #-------------------------------------------------------------------------------
 
 NETWORK_FILES="src/vnm_mad/remotes/OpenNebulaNetwork.rb \
+               src/vnm_mad/remotes/OpenNebulaNetwork.conf \
                src/vnm_mad/remotes/Firewall.rb \
                src/vnm_mad/remotes/OpenNebulaNic.rb"
 
@@ -900,6 +952,7 @@ NETWORK_VMWARE_FILES="src/vnm_mad/remotes/vmware/clean \
 #   - VMWARE TM, $VAR_LOCATION/tm/vmware
 #   - LVM TM, $VAR_LOCATION/tm/lvm
 #   - CEPH TM, $VAR_LOCATION/tm/ceph
+#   - DEV TM, $VAR_LOCATION/tm/dev
 #-------------------------------------------------------------------------------
 
 TM_FILES="src/tm_mad/tm_common.sh"
@@ -991,6 +1044,15 @@ TM_CEPH_FILES="src/tm_mad/ceph/clone \
                  src/tm_mad/ceph/postmigrate \
                  src/tm_mad/ceph/delete"
 
+TM_DEV_FILES="src/tm_mad/dev/clone \
+                 src/tm_mad/dev/ln \
+                 src/tm_mad/dev/mv \
+                 src/tm_mad/dev/mvds \
+                 src/tm_mad/dev/cpds \
+                 src/tm_mad/dev/premigrate \
+                 src/tm_mad/dev/postmigrate \
+                 src/tm_mad/dev/delete"
+
 #-------------------------------------------------------------------------------
 # Datastore drivers, to be installed under $REMOTES_LOCATION/datastore
 #   - Dummy Image Repository, $REMOTES_LOCATION/datastore/dummy
@@ -1041,6 +1103,13 @@ DATASTORE_DRIVER_CEPH_SCRIPTS="src/datastore_mad/remotes/ceph/cp \
                          src/datastore_mad/remotes/ceph/clone \
                          src/datastore_mad/remotes/ceph/ceph.conf"
 
+DATASTORE_DRIVER_DEV_SCRIPTS="src/datastore_mad/remotes/dev/cp \
+                         src/datastore_mad/remotes/dev/mkfs \
+                         src/datastore_mad/remotes/dev/stat \
+                         src/datastore_mad/remotes/dev/rm \
+                         src/datastore_mad/remotes/dev/monitor \
+                         src/datastore_mad/remotes/dev/clone"
+
 #-------------------------------------------------------------------------------
 # Migration scripts for onedb command, to be installed under $LIB_LOCATION
 #-------------------------------------------------------------------------------
@@ -1086,7 +1155,7 @@ ONEDB_SHARED_MIGRATOR_FILES="src/onedb/shared/2.0_to_2.9.80.rb \
                              src/onedb/shared/4.4.1_to_4.5.80.rb\
                              src/onedb/shared/4.5.80_to_4.6.0.rb"
 
-ONEDB_LOCAL_MIGRATOR_FILES=""
+ONEDB_LOCAL_MIGRATOR_FILES="src/onedb/local/4.5.80_to_4.7.80.rb"
 
 #-------------------------------------------------------------------------------
 # Configuration files for OpenNebula, to be installed under $ETC_LOCATION
@@ -1101,6 +1170,13 @@ VMWARE_ETC_FILES="src/vmm_mad/remotes/vmware/vmwarerc"
 EC2_ETC_FILES="src/vmm_mad/remotes/ec2/ec2_driver.conf \
                src/vmm_mad/remotes/ec2/ec2_driver.default"
 
+SL_ETC_FILES="src/vmm_mad/remotes/sl/sl_driver.conf \
+              src/vmm_mad/remotes/sl/sl_driver.default"
+
+AZ_ETC_FILES="src/vmm_mad/remotes/az/az_driver.conf \
+              src/vmm_mad/remotes/az/az_driver.default"
+
+
 #-------------------------------------------------------------------------------
 # Virtualization drivers config. files, to be installed under $ETC_LOCATION
 #   - ssh, $ETC_LOCATION/vmm_exec
@@ -1206,8 +1282,7 @@ COMMON_CLOUD_LIB_FILES="src/cloud/common/CloudServer.rb \
 
 COMMON_CLOUD_CLIENT_LIB_FILES="src/cloud/common/CloudClient.rb"
 
-CLOUD_AUTH_LIB_FILES="src/cloud/common/CloudAuth/OCCICloudAuth.rb \
-                      src/cloud/common/CloudAuth/SunstoneCloudAuth.rb \
+CLOUD_AUTH_LIB_FILES="src/cloud/common/CloudAuth/SunstoneCloudAuth.rb \
                       src/cloud/common/CloudAuth/EC2CloudAuth.rb \
                       src/cloud/common/CloudAuth/X509CloudAuth.rb \
                       src/cloud/common/CloudAuth/OneGateCloudAuth.rb \
@@ -1310,46 +1385,6 @@ ECO_ETC_FILES="src/cloud/ec2/etc/econe.conf"
 
 ECO_ETC_TEMPLATE_FILES="src/cloud/ec2/etc/templates/m1.small.erb"
 
-#-----------------------------------------------------------------------------
-# OCCI files
-#-----------------------------------------------------------------------------
-
-OCCI_LIB_FILES="src/cloud/occi/lib/OCCIServer.rb \
-                src/cloud/occi/lib/occi-server.rb \
-                src/cloud/occi/lib/occi_application.rb \
-                src/cloud/occi/lib/OCCIClient.rb \
-                src/cloud/occi/lib/VirtualMachineOCCI.rb \
-                src/cloud/occi/lib/VirtualMachinePoolOCCI.rb \
-                src/cloud/occi/lib/VirtualNetworkOCCI.rb \
-                src/cloud/occi/lib/VirtualNetworkPoolOCCI.rb \
-                src/cloud/occi/lib/UserOCCI.rb \
-                src/cloud/occi/lib/UserPoolOCCI.rb \
-                src/cloud/occi/lib/ImageOCCI.rb \
-                src/cloud/occi/lib/ImagePoolOCCI.rb \
-                src/sunstone/OpenNebulaVNC.rb"
-
-OCCI_LIB_CLIENT_FILES="src/cloud/occi/lib/OCCIClient.rb"
-
-OCCI_BIN_FILES="src/cloud/occi/bin/occi-server \
-               src/cloud/occi/bin/occi-compute \
-               src/cloud/occi/bin/occi-network \
-               src/cloud/occi/bin/occi-instance-type \
-               src/cloud/occi/bin/occi-storage"
-
-OCCI_BIN_CLIENT_FILES="src/cloud/occi/bin/occi-compute \
-               src/cloud/occi/bin/occi-network \
-               src/cloud/occi/bin/occi-instance-type \
-               src/cloud/occi/bin/occi-storage"
-
-OCCI_ETC_FILES="src/cloud/occi/etc/occi-server.conf"
-
-OCCI_ETC_TEMPLATE_FILES="src/cloud/occi/etc/templates/common.erb \
-                    src/cloud/occi/etc/templates/custom.erb \
-                    src/cloud/occi/etc/templates/small.erb \
-                    src/cloud/occi/etc/templates/medium.erb \
-                    src/cloud/occi/etc/templates/network.erb \
-                    src/cloud/occi/etc/templates/large.erb"
-
 #-------------------------------------------------------------------------------
 # Marketplace Client
 #-------------------------------------------------------------------------------
@@ -1429,7 +1464,7 @@ SUNSTONE_ETC_FILES="src/sunstone/etc/sunstone-server.conf \
 SUNSTONE_ETC_VIEW_FILES="src/sunstone/etc/sunstone-views/admin.yaml \
                     src/sunstone/etc/sunstone-views/user.yaml \
                     src/sunstone/etc/sunstone-views/cloud.yaml \
-                     src/sunstone/etc/sunstone-views/vdcadmin.yaml"
+                    src/sunstone/etc/sunstone-views/vdcadmin.yaml"
 
 SUNSTONE_MODELS_FILES="src/sunstone/models/OpenNebulaJSON.rb \
                        src/sunstone/models/SunstoneServer.rb \
@@ -1483,6 +1518,7 @@ SUNSTONE_PUBLIC_JS_PLUGINS_FILES="\
                         src/sunstone/public/js/plugins/oneflow-dashboard.js \
                         src/sunstone/public/js/plugins/oneflow-services.js \
                         src/sunstone/public/js/plugins/oneflow-templates.js \
+                        src/sunstone/public/js/plugins/support-tab.js \
                         src/sunstone/public/js/plugins/zones-tab.js"
 
 SUNSTONE_ROUTES_FILES="src/sunstone/routes/oneflow.rb"
@@ -1497,6 +1533,7 @@ src/sunstone/public/vendor/flot/jquery.flot.navigate.min.js \
 src/sunstone/public/vendor/flot/jquery.flot.pie.min.js \
 src/sunstone/public/vendor/flot/jquery.flot.resize.min.js \
 src/sunstone/public/vendor/flot/jquery.flot.stack.min.js \
+src/sunstone/public/vendor/flot/jquery.flot.tooltip.min.js \
 src/sunstone/public/vendor/flot/LICENSE.txt \
 src/sunstone/public/vendor/flot/NOTICE"
 
@@ -1565,7 +1602,7 @@ SUNSTONE_PUBLIC_NEW_VENDOR_FOUNDATION="\
   src/sunstone/public/bower_components/foundation/js/foundation.min.js"
 
 SUNSTONE_PUBLIC_NEW_VENDOR_JQUERY="\
-                        src/sunstone/public/vendor/4.0/jquery-1.11.0.min.js \
+                        src/sunstone/public/vendor/4.0/jquery-2.1.1.min.js \
                         src/sunstone/public/vendor/4.0/jquery-1.11.0.min.map \
                         src/sunstone/public/vendor/4.0/jquery-migrate-1.2.1.js"
 
@@ -1626,6 +1663,17 @@ SUNSTONE_PUBLIC_IMAGES_FILES="src/sunstone/public/images/ajax-loader.gif \
                         src/sunstone/public/images/sort_desc_disabled.png\
 "
 
+SUNSTONE_PUBLIC_LOGOS_FILES="src/sunstone/public/images/logos/arch.png \
+                        src/sunstone/public/images/logos/centos.png \
+                        src/sunstone/public/images/logos/debian.png \
+                        src/sunstone/public/images/logos/fedora.png \
+                        src/sunstone/public/images/logos/linux.png \
+                        src/sunstone/public/images/logos/redhat.png \
+                        src/sunstone/public/images/logos/ubuntu.png \
+                        src/sunstone/public/images/logos/windowsxp.png \
+                        src/sunstone/public/images/logos/windows8.png \
+"
+
 SUNSTONE_PUBLIC_LOCALE_CA="\
 src/sunstone/locale/languages/ca.js \
 src/sunstone/locale/languages/ca_datatable.txt"
@@ -1778,10 +1826,7 @@ MAN_FILES="share/man/oneacct.1.gz \
         share/man/econe-start-instances.1.gz \
         share/man/econe-stop-instances.1.gz \
         share/man/econe-terminate-instances.1.gz \
-        share/man/econe-upload.1.gz \
-        share/man/occi-compute.1.gz \
-        share/man/occi-network.1.gz \
-        share/man/occi-storage.1.gz"
+        share/man/econe-upload.1.gz"
 
 #-----------------------------------------------------------------------------
 # Ruby VENDOR files
