@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
+/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -25,10 +25,11 @@
 
 const char * AclManager::table = "acl";
 
-const char * AclManager::db_names = "oid, user, resource, rights";
+const char * AclManager::db_names = "oid, user, resource, rights, zone";
 
 const char * AclManager::db_bootstrap = "CREATE TABLE IF NOT EXISTS "
-    "acl (oid INT PRIMARY KEY, user BIGINT, resource BIGINT, rights BIGINT)";
+    "acl (oid INT PRIMARY KEY, user BIGINT, resource BIGINT, "
+    "rights BIGINT, zone BIGINT, UNIQUE(user, resource, rights, zone))";
 
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
@@ -47,7 +48,13 @@ int AclManager::init_cb(void *nil, int num, char **values, char **names)
 
 /* -------------------------------------------------------------------------- */
 
-AclManager::AclManager(SqlDB * _db) : db(_db), lastOID(-1)
+AclManager::AclManager(
+    SqlDB * _db,
+    int     _zone_id,
+    bool    _is_federation_slave,
+    time_t  _timer_period)
+        :zone_id(_zone_id), db(_db), lastOID(-1),
+        is_federation_slave(_is_federation_slave), timer_period(_timer_period)
 {
     ostringstream oss;
 
@@ -62,30 +69,40 @@ AclManager::AclManager(SqlDB * _db) : db(_db), lastOID(-1)
 
     unset_callback();
 
+    am.addListener(this);
+
+    //Federation slaves do not need to init the pool
+    if (is_federation_slave)
+    {
+        return;
+    }
+
     if (lastOID == -1)
     {
         // Add a default rules for the ACL engine
         string error_str;
 
         // Users in group USERS can create standard resources
-        // @1 VM+NET+IMAGE+TEMPLATE/* CREATE
-        add_rule(AclRule::GROUP_ID | 
+        // @1 VM+NET+IMAGE+TEMPLATE+DOCUMENT/* CREATE #<local-zone>
+        add_rule(AclRule::GROUP_ID |
                     1,
-                 AclRule::ALL_ID | 
-                    PoolObjectSQL::VM | 
+                 AclRule::ALL_ID |
+                    PoolObjectSQL::VM |
                     PoolObjectSQL::NET |
-                    PoolObjectSQL::IMAGE | 
-                    PoolObjectSQL::TEMPLATE,
+                    PoolObjectSQL::IMAGE |
+                    PoolObjectSQL::TEMPLATE |
+                    PoolObjectSQL::DOCUMENT,
                  AuthRequest::CREATE,
+                 AclRule::INDIVIDUAL_ID |
+                     zone_id,
                  error_str);
 
-        // Users in USERS can deploy VMs in any HOST
-        // @1 HOST/* MANAGE
-        add_rule(AclRule::GROUP_ID | 
-                    1,
-                 AclRule::ALL_ID | 
-                    PoolObjectSQL::HOST,
-                 AuthRequest::MANAGE,
+        // * ZONE/* USE *
+        add_rule(AclRule::ALL_ID,
+                 AclRule::ALL_ID |
+                    PoolObjectSQL::ZONE,
+                 AuthRequest::USE,
+                 AclRule::ALL_ID,
                  error_str);
     }
 }
@@ -93,9 +110,67 @@ AclManager::AclManager(SqlDB * _db) : db(_db), lastOID(-1)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
+extern "C" void * acl_action_loop(void *arg)
+{
+    AclManager * aclm;
+
+    if ( arg == 0 )
+    {
+        return 0;
+    }
+
+    NebulaLog::log("ACL",Log::INFO,"ACL Manager started.");
+
+    aclm = static_cast<AclManager *>(arg);
+
+    aclm->am.loop(aclm->timer_period,0);
+
+    NebulaLog::log("ACL",Log::INFO,"ACL Manager stopped.");
+
+    return 0;
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
 int AclManager::start()
 {
-    return select();
+    int rc;
+
+    NebulaLog::log("ACL",Log::INFO,"Starting ACL Manager...");
+
+    rc = select();
+
+    if (is_federation_slave)
+    {
+        pthread_attr_t    pattr;
+
+        pthread_attr_init (&pattr);
+        pthread_attr_setdetachstate (&pattr, PTHREAD_CREATE_JOINABLE);
+
+        rc += pthread_create(&acl_thread,&pattr,acl_action_loop,(void *) this);
+    }
+    else
+    {
+        NebulaLog::log("ACL",Log::INFO,"ACL Manager started.");
+    }
+
+    return rc;
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+void AclManager::finalize()
+{
+    if (is_federation_slave)
+    {
+        am.trigger(ACTION_FINALIZE,0);
+    }
+    else
+    {
+        NebulaLog::log("ACL",Log::INFO,"ACL Manager stopped.");
+    }
 }
 
 /* -------------------------------------------------------------------------- */
@@ -122,7 +197,7 @@ AclManager::~AclManager()
 
 const bool AclManager::authorize(
         int                     uid,
-        int                     gid,
+        const set<int>&         user_groups,
         const PoolObjectAuth&   obj_perms,
         AuthRequest::Operation  op)
 {
@@ -136,8 +211,8 @@ const bool AclManager::authorize(
 
     if ( obj_perms.oid >= 0 )
     {
-        resource_oid_req = obj_perms.obj_type | 
-                           AclRule::INDIVIDUAL_ID | 
+        resource_oid_req = obj_perms.obj_type |
+                           AclRule::INDIVIDUAL_ID |
                            obj_perms.oid;
     }
     else
@@ -149,8 +224,8 @@ const bool AclManager::authorize(
 
     if ( obj_perms.gid >= 0 )
     {
-        resource_gid_req = obj_perms.obj_type | 
-                           AclRule::GROUP_ID | 
+        resource_gid_req = obj_perms.obj_type |
+                           AclRule::GROUP_ID |
                            obj_perms.gid;
     }
     else
@@ -158,15 +233,32 @@ const bool AclManager::authorize(
         resource_gid_req = AclRule::NONE_ID;
     }
 
+    long long resource_cid_req;
+
+    if ( obj_perms.cid >= 0 )
+    {
+        resource_cid_req = obj_perms.obj_type |
+                           AclRule::CLUSTER_ID |
+                           obj_perms.cid;
+    }
+    else
+    {
+        resource_cid_req = AclRule::NONE_ID;
+    }
+
     long long resource_all_req  = obj_perms.obj_type | AclRule::ALL_ID;
     long long rights_req        = op;
 
-    long long resource_oid_mask = obj_perms.obj_type | 
-                                  AclRule::INDIVIDUAL_ID | 
+    long long resource_oid_mask = obj_perms.obj_type |
+                                  AclRule::INDIVIDUAL_ID |
                                   0x00000000FFFFFFFFLL;
 
-    long long resource_gid_mask = obj_perms.obj_type | 
-                                  AclRule::GROUP_ID | 
+    long long resource_gid_mask = obj_perms.obj_type |
+                                  AclRule::GROUP_ID |
+                                  0x00000000FFFFFFFFLL;
+
+    long long resource_cid_mask = obj_perms.obj_type |
+                                  AclRule::CLUSTER_ID |
                                   0x00000000FFFFFFFFLL;
 
     // Create a temporal rule, to log the request
@@ -180,15 +272,20 @@ const bool AclManager::authorize(
     {
         log_resource = resource_gid_req;
     }
+    else if ( obj_perms.cid >= 0 )
+    {
+        log_resource = resource_cid_req;
+    }
     else
     {
         log_resource = resource_all_req;
     }
 
-    AclRule log_rule(-1, 
-                     AclRule::INDIVIDUAL_ID | uid, 
+    AclRule log_rule(-1,
+                     AclRule::INDIVIDUAL_ID | uid,
                      log_resource,
-                     rights_req);
+                     rights_req,
+                     AclRule::INDIVIDUAL_ID | zone_id);
 
     oss << "Request " << log_rule.to_str();
     NebulaLog::log("ACL",Log::DDEBUG,oss);
@@ -202,7 +299,7 @@ const bool AclManager::authorize(
     AclRule other_rule;
     multimap<long long, AclRule *> tmp_rules;
 
-    obj_perms.get_acl_rules(owner_rule, group_rule, other_rule);
+    obj_perms.get_acl_rules(owner_rule, group_rule, other_rule, zone_id);
 
     tmp_rules.insert( make_pair(owner_rule.user, &owner_rule) );
     tmp_rules.insert( make_pair(group_rule.user, &group_rule) );
@@ -216,10 +313,12 @@ const bool AclManager::authorize(
     auth     = match_rules_wrapper(user_req,
                                    resource_oid_req,
                                    resource_gid_req,
+                                   resource_cid_req,
                                    resource_all_req,
                                    rights_req,
                                    resource_oid_mask,
                                    resource_gid_mask,
+                                   resource_cid_mask,
                                    tmp_rules);
     if ( auth == true )
     {
@@ -234,10 +333,12 @@ const bool AclManager::authorize(
     auth     = match_rules_wrapper(user_req,
                                    resource_oid_req,
                                    resource_gid_req,
+                                   resource_cid_req,
                                    resource_all_req,
                                    rights_req,
                                    resource_oid_mask,
                                    resource_gid_mask,
+                                   resource_cid_mask,
                                    tmp_rules);
     if ( auth == true )
     {
@@ -245,21 +346,28 @@ const bool AclManager::authorize(
     }
 
     // ----------------------------------------------------------
-    // Look for rules that apply to the user's group
+    // Look for rules that apply to each one of the user's groups
     // ----------------------------------------------------------
 
-    user_req = AclRule::GROUP_ID | gid;
-    auth     = match_rules_wrapper(user_req,
-                                   resource_oid_req,
-                                   resource_gid_req,
-                                   resource_all_req,
-                                   rights_req,
-                                   resource_oid_mask,
-                                   resource_gid_mask,
-                                   tmp_rules);
-    if ( auth == true )
+    set<int>::iterator  g_it;
+
+    for (g_it = user_groups.begin(); g_it != user_groups.end(); g_it++)
     {
-        return true;
+        user_req = AclRule::GROUP_ID | *g_it;
+        auth     = match_rules_wrapper(user_req,
+                                       resource_oid_req,
+                                       resource_gid_req,
+                                       resource_cid_req,
+                                       resource_all_req,
+                                       rights_req,
+                                       resource_oid_mask,
+                                       resource_gid_mask,
+                                       resource_cid_mask,
+                                       tmp_rules);
+        if ( auth == true )
+        {
+            return true;
+        }
     }
 
     oss.str("No more rules, permission not granted ");
@@ -275,10 +383,12 @@ bool AclManager::match_rules_wrapper(
         long long user_req,
         long long resource_oid_req,
         long long resource_gid_req,
+        long long resource_cid_req,
         long long resource_all_req,
         long long rights_req,
         long long individual_obj_type,
         long long group_obj_type,
+        long long cluster_obj_type,
         multimap<long long, AclRule*> &tmp_rules)
 {
     bool auth = false;
@@ -288,10 +398,12 @@ bool AclManager::match_rules_wrapper(
             user_req,
             resource_oid_req,
             resource_gid_req,
+            resource_cid_req,
             resource_all_req,
             rights_req,
             individual_obj_type,
             group_obj_type,
+            cluster_obj_type,
             tmp_rules);
 
     if ( auth == true )
@@ -306,10 +418,12 @@ bool AclManager::match_rules_wrapper(
             user_req,
             resource_oid_req,
             resource_gid_req,
+            resource_cid_req,
             resource_all_req,
             rights_req,
             individual_obj_type,
             group_obj_type,
+            cluster_obj_type,
             acl_rules);
 
     unlock();
@@ -324,10 +438,12 @@ bool AclManager::match_rules(
         long long user_req,
         long long resource_oid_req,
         long long resource_gid_req,
+        long long resource_cid_req,
         long long resource_all_req,
         long long rights_req,
         long long resource_oid_mask,
         long long resource_gid_mask,
+        long long resource_cid_mask,
         multimap<long long, AclRule*> &rules)
 
 {
@@ -339,6 +455,10 @@ bool AclManager::match_rules(
     pair<multimap<long long, AclRule *>::iterator,
          multimap<long long, AclRule *>::iterator>  index;
 
+    long long zone_oid_mask = AclRule::INDIVIDUAL_ID | 0x00000000FFFFFFFFLL;
+    long long zone_req      = AclRule::INDIVIDUAL_ID | zone_id;
+    long long zone_all_req  = AclRule::ALL_ID;
+
     index = rules.equal_range( user_req );
 
     for ( it = index.first; it != index.second; it++)
@@ -348,6 +468,14 @@ bool AclManager::match_rules(
         NebulaLog::log("ACL",Log::DDEBUG,oss);
 
         auth =
+          (
+            // Rule applies in any Zone
+            ( ( it->second->zone & zone_all_req ) == zone_all_req )
+            ||
+            // Rule applies in this Zone
+            ( ( it->second->zone & zone_oid_mask ) == zone_req )
+          )
+          &&
           // Rule grants the requested rights
           ( ( it->second->rights & rights_req ) == rights_req )
           &&
@@ -360,6 +488,9 @@ bool AclManager::match_rules(
             ||
             // Or rule's object type and individual object ID match
             ( ( it->second->resource & resource_oid_mask ) == resource_oid_req )
+            ||
+            // Or rule's object type and cluster object ID match
+            ( ( it->second->resource & resource_cid_mask ) == resource_cid_req )
           );
 
         if ( auth == true )
@@ -378,8 +509,17 @@ bool AclManager::match_rules(
 /* -------------------------------------------------------------------------- */
 
 int AclManager::add_rule(long long user, long long resource, long long rights,
-                        string& error_str)
+                        long long zone, string& error_str)
 {
+    if (is_federation_slave)
+    {
+        NebulaLog::log("ONE",Log::ERROR,
+                "AclManager::add_rule called, but this "
+                "OpenNebula is a federation slave");
+
+        return -1;
+    }
+
     lock();
 
     if (lastOID == INT_MAX)
@@ -387,7 +527,7 @@ int AclManager::add_rule(long long user, long long resource, long long rights,
         lastOID = -1;
     }
 
-    AclRule * rule = new AclRule(++lastOID, user, resource, rights);
+    AclRule * rule = new AclRule(++lastOID, user, resource, rights, zone);
 
     ostringstream   oss;
     int             rc;
@@ -476,6 +616,15 @@ int AclManager::del_rule(int oid, string& error_str)
     int         rc;
     bool        found = false;
 
+    if (is_federation_slave)
+    {
+        NebulaLog::log("ONE",Log::ERROR,
+                "AclManager::del_rule called, but this "
+                "OpenNebula is a federation slave");
+
+        return -1;
+    }
+
     lock();
 
     // Check the rule exists
@@ -533,11 +682,13 @@ int AclManager::del_rule(int oid, string& error_str)
         return -1;
     }
 
-    delete it->second;
+    rule = it->second;
 
     acl_rules.erase( it );
     acl_rules_oids.erase( oid );
 
+    delete rule;
+
     unlock();
     return 0;
 }
@@ -545,6 +696,52 @@ int AclManager::del_rule(int oid, string& error_str)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
+int AclManager::del_rule(
+        long long user,
+        long long resource,
+        long long rights,
+        long long zone,
+        string&   error_str)
+{
+    lock();
+
+    AclRule * rule = new AclRule(-1, user, resource, rights, zone);
+
+    int oid = -1;
+    bool found = false;
+
+    multimap<long long, AclRule *>::iterator        it;
+    pair<multimap<long long, AclRule *>::iterator,
+         multimap<long long, AclRule *>::iterator>  index;
+
+    index = acl_rules.equal_range( user );
+
+    for ( it = index.first; (it != index.second && !found); it++)
+    {
+        found = *(it->second) == *rule;
+
+        if (found)
+        {
+            oid = it->second->get_oid();
+        }
+    }
+
+    unlock();
+
+    if (oid != -1)
+    {
+        return del_rule(oid, error_str);
+    }
+    else
+    {
+        error_str = "Rule does not exist";
+        return -1;
+    }
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
 void AclManager::del_uid_rules(int uid)
 {
     long long user_req = AclRule::INDIVIDUAL_ID | uid;
@@ -574,6 +771,32 @@ void AclManager::del_gid_rules(int gid)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
+void AclManager::del_cid_rules(int cid)
+{
+    long long request = AclRule::CLUSTER_ID | cid;
+    long long resource_gid_mask = AclRule::CLUSTER_ID |
+                                  0x00000000FFFFFFFFLL;
+
+    // Delete rules that match
+    // __  __/%cid  __
+    del_resource_matching_rules(request, resource_gid_mask);
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+void AclManager::del_zid_rules(int zid)
+{
+    long long request = AclRule::INDIVIDUAL_ID | zid;
+
+    // Delete rules that match
+    // __  __/__  __ #zid
+    del_zone_matching_rules(request);
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
 void AclManager::del_resource_rules(int oid, PoolObjectSQL::ObjectType obj_type)
 {
     long long request = obj_type |
@@ -651,13 +874,43 @@ void AclManager::del_resource_matching_rules(long long resource_req,
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
+void AclManager::del_zone_matching_rules(long long zone_req)
+{
+    multimap<long long, AclRule *>::iterator        it;
+
+    vector<int>             oids;
+    vector<int>::iterator   oid_it;
+    string                  error_str;
+
+    lock();
+
+    for ( it = acl_rules.begin(); it != acl_rules.end(); it++ )
+    {
+        if ( it->second->zone == zone_req )
+        {
+            oids.push_back(it->second->oid);
+        }
+    }
+
+    unlock();
+
+    for ( oid_it = oids.begin() ; oid_it < oids.end(); oid_it++ )
+    {
+        del_rule(*oid_it, error_str);
+    }
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
 void AclManager::reverse_search(int                       uid,
-                                int                       gid,
+                                const set<int>&           user_groups,
                                 PoolObjectSQL::ObjectType obj_type,
                                 AuthRequest::Operation    op,
                                 bool&                     all,
                                 vector<int>&              oids,
-                                vector<int>&              gids)
+                                vector<int>&              gids,
+                                vector<int>&              cids)
 {
     ostringstream oss;
 
@@ -669,6 +922,7 @@ void AclManager::reverse_search(int                       uid,
     long long resource_oid_req = obj_type | AclRule::INDIVIDUAL_ID;
     long long resource_gid_req = obj_type | AclRule::GROUP_ID;
     long long resource_all_req = obj_type | AclRule::ALL_ID;
+    long long resource_cid_req = obj_type | AclRule::CLUSTER_ID;
     long long rights_req       = op;
 
     long long resource_oid_mask =
@@ -677,6 +931,13 @@ void AclManager::reverse_search(int                       uid,
     long long resource_gid_mask  =
             ( obj_type | AclRule::GROUP_ID );
 
+    long long resource_cid_mask  =
+            ( obj_type | AclRule::CLUSTER_ID );
+
+    long long zone_oid_req =
+            AclRule::INDIVIDUAL_ID | zone_id;
+
+    long long zone_all_req = AclRule::ALL_ID;
 
     // Create a temporal rule, to log the request
     long long log_resource;
@@ -686,7 +947,8 @@ void AclManager::reverse_search(int                       uid,
     AclRule log_rule(-1,
                      AclRule::INDIVIDUAL_ID | uid,
                      log_resource,
-                     rights_req);
+                     rights_req,
+                     zone_oid_req);
 
     oss << "Reverse search request " << log_rule.to_str();
     NebulaLog::log("ACL",Log::DDEBUG,oss);
@@ -695,27 +957,42 @@ void AclManager::reverse_search(int                       uid,
     // Look for the rules that match
     // ---------------------------------------------------
 
-    long long user_reqs[] =
+    vector<long long>           user_reqs;
+    vector<long long>::iterator reqs_it;
+
+    set<int>::iterator  g_it;
+
+    // rules that apply to everyone
+    user_reqs.push_back(AclRule::ALL_ID);
+
+    // rules that apply to the individual user id
+    user_reqs.push_back(AclRule::INDIVIDUAL_ID | uid);
+
+    // rules that apply to each one of the user's groups
+    for (g_it = user_groups.begin(); g_it != user_groups.end(); g_it++)
     {
-        AclRule::ALL_ID,                // rules that apply to everyone
-        AclRule::INDIVIDUAL_ID | uid,   // rules that apply to the individual user id
-        AclRule::GROUP_ID | gid         // rules that apply to the user's groups
-    };
+        user_reqs.push_back(AclRule::GROUP_ID | *g_it);
+    }
 
     all = false;
 
-    for ( int i=0; i<3; i++ )
+    for (reqs_it = user_reqs.begin(); reqs_it != user_reqs.end(); reqs_it++)
     {
-        long long user_req = user_reqs[i];
-
         lock();
 
-        index = acl_rules.equal_range( user_req );
+        index = acl_rules.equal_range( *reqs_it );
 
         for ( it = index.first; it != index.second; it++)
         {
-            // Rule grants the requested rights
-            if ( ( it->second->rights & rights_req ) == rights_req )
+                // Rule grants the requested rights
+            if ( ( ( it->second->rights & rights_req ) == rights_req )
+                 &&
+                 // Rule applies in this zone or in all zones
+                 ( ( it->second->zone == zone_oid_req )
+                   ||
+                   ( it->second->zone == zone_all_req )
+                 )
+               )
             {
                 oss.str("");
                 oss << "> Rule  " << it->second->to_str();
@@ -739,6 +1016,13 @@ void AclManager::reverse_search(int                       uid,
                 {
                     oids.push_back(it->second->resource_id());
                 }
+
+                // Rule grants permission for all objects of a cluster
+                if ( ( it->second->resource & resource_cid_mask ) == resource_cid_req )
+                {
+                    cids.push_back(it->second->resource_id());
+                }
+
             }
         }
 
@@ -748,6 +1032,7 @@ void AclManager::reverse_search(int                       uid,
         {
             oids.clear();
             gids.clear();
+            cids.clear();
         }
     }
 }
@@ -784,11 +1069,12 @@ void AclManager::update_lastOID()
 
 int AclManager::select_cb(void *nil, int num, char **values, char **names)
 {
-    if ( (num != 4)   ||
+    if ( (num != 5)   ||
          (!values[0]) ||
          (!values[1]) ||
          (!values[2]) ||
-         (!values[3]) )
+         (!values[3]) ||
+         (!values[4]) )
     {
         return -1;
     }
@@ -800,7 +1086,7 @@ int AclManager::select_cb(void *nil, int num, char **values, char **names)
 
     long long rule_values[3];
 
-    for ( int i = 0; i < 3; i++ )
+    for ( int i = 0; i < 4; i++ )
     {
         iss.str( values[i+1] );
 
@@ -814,10 +1100,11 @@ int AclManager::select_cb(void *nil, int num, char **values, char **names)
         iss.clear();
     }
 
-    AclRule * rule = new AclRule(oid, 
-                                 rule_values[0], 
+    AclRule * rule = new AclRule(oid,
+                                 rule_values[0],
                                  rule_values[1],
-                                 rule_values[2]);
+                                 rule_values[2],
+                                 rule_values[3]);
 
     oss << "Loading ACL Rule " << rule->to_str();
     NebulaLog::log("ACL",Log::DDEBUG,oss);
@@ -840,8 +1127,15 @@ int AclManager::select()
 
     set_callback(static_cast<Callbackable::Callback>(&AclManager::select_cb));
 
+    lock();
+
+    acl_rules.clear();
+    acl_rules_oids.clear();
+
     rc = db->exec(oss,this);
 
+    unlock();
+
     unset_callback();
 
     return rc;
@@ -861,7 +1155,8 @@ int AclManager::insert(AclRule * rule, SqlDB * db)
         <<  rule->oid       << ","
         <<  rule->user      << ","
         <<  rule->resource  << ","
-        <<  rule->rights    << ")";
+        <<  rule->rights    << ","
+        <<  rule->zone      << ")";
 
     rc = db->exec(oss);
 
@@ -911,3 +1206,25 @@ int AclManager::dump(ostringstream& oss)
 
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
+
+void AclManager::do_action(const string &action, void * arg)
+{
+    if (action == ACTION_TIMER)
+    {
+        select();
+    }
+    else if (action == ACTION_FINALIZE)
+    {
+        NebulaLog::log("ACL",Log::INFO,"Stopping ACL Manager...");
+    }
+    else
+    {
+        ostringstream oss;
+        oss << "Unknown action name: " << action;
+
+        NebulaLog::log("ACL", Log::ERROR, oss);
+    }
+}
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
