@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             */
+/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -32,11 +32,14 @@ const int    DatastorePool::SYSTEM_DS_ID   = 0;
 const string DatastorePool::DEFAULT_DS_NAME = "default";
 const int    DatastorePool::DEFAULT_DS_ID   = 1;
 
+const string DatastorePool::FILE_DS_NAME = "files";
+const int    DatastorePool::FILE_DS_ID   = 2;
+
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
 DatastorePool::DatastorePool(SqlDB * db):
-                        PoolSQL(db, Datastore::table, true)
+                        PoolSQL(db, Datastore::table, true, true)
 {
     ostringstream oss;
     string        error_str;
@@ -44,17 +47,15 @@ DatastorePool::DatastorePool(SqlDB * db):
     if (get_lastOID() == -1) //lastOID is set in PoolSQL::init_cb
     {
         DatastoreTemplate * ds_tmpl;
-        Datastore *         ds;
-
-        int     rc;
+        int    rc;
 
         // ---------------------------------------------------------------------
-        // Create the system datastore 
+        // Create the system datastore
         // ---------------------------------------------------------------------
 
-        oss << "NAME      = " << SYSTEM_DS_NAME << endl
-            << "DS_MAD    = -" << endl
-            << "TM_MAD    = shared";
+        oss << "NAME   = " << SYSTEM_DS_NAME << endl
+            << "TYPE   = SYSTEM_DS" << endl
+            << "TM_MAD = shared";
 
         ds_tmpl = new DatastoreTemplate;
         rc = ds_tmpl->parse_str_or_xml(oss.str(), error_str);
@@ -68,6 +69,7 @@ DatastorePool::DatastorePool(SqlDB * db):
                 GroupPool::ONEADMIN_ID,
                 UserPool::oneadmin_name,
                 GroupPool::ONEADMIN_NAME,
+                0137,
                 ds_tmpl,
                 &rc,
                 ClusterPool::NONE_CLUSTER_ID,
@@ -80,13 +82,14 @@ DatastorePool::DatastorePool(SqlDB * db):
         }
 
         // ---------------------------------------------------------------------
-        // Create the default datastore 
+        // Create the default datastore
         // ---------------------------------------------------------------------
         oss.str("");
 
-        oss << "NAME      = "   << DEFAULT_DS_NAME << endl
-            << "DS_MAD    = fs" << endl
-            << "TM_MAD    = shared";
+        oss << "NAME   = "   << DEFAULT_DS_NAME << endl
+            << "TYPE   = IMAGE_DS" << endl
+            << "DS_MAD = fs" << endl
+            << "TM_MAD = shared";
 
         ds_tmpl = new DatastoreTemplate;
         rc = ds_tmpl->parse_str_or_xml(oss.str(), error_str);
@@ -100,6 +103,7 @@ DatastorePool::DatastorePool(SqlDB * db):
                 GroupPool::ONEADMIN_ID,
                 UserPool::oneadmin_name,
                 GroupPool::ONEADMIN_NAME,
+                0137,
                 ds_tmpl,
                 &rc,
                 ClusterPool::NONE_CLUSTER_ID,
@@ -111,17 +115,39 @@ DatastorePool::DatastorePool(SqlDB * db):
             goto error_bootstrap;
         }
 
-        ds = get(rc, true);
+        // ---------------------------------------------------------------------
+        // Create the default file datastore
+        // ---------------------------------------------------------------------
+        oss.str("");
 
-        ds->set_permissions(
-                -1,-1,-1,
-                -1,-1,-1,
-                1,-1,-1,
+        oss << "NAME   = "   << FILE_DS_NAME << endl
+            << "TYPE   = FILE_DS" << endl
+            << "DS_MAD = fs" << endl
+            << "TM_MAD = ssh";
+
+        ds_tmpl = new DatastoreTemplate;
+        rc = ds_tmpl->parse_str_or_xml(oss.str(), error_str);
+
+        if( rc < 0 )
+        {
+            goto error_bootstrap;
+        }
+
+        allocate(UserPool::ONEADMIN_ID,
+                GroupPool::ONEADMIN_ID,
+                UserPool::oneadmin_name,
+                GroupPool::ONEADMIN_NAME,
+                0137,
+                ds_tmpl,
+                &rc,
+                ClusterPool::NONE_CLUSTER_ID,
+                ClusterPool::NONE_CLUSTER_NAME,
                 error_str);
 
-        update(ds);
-
-        ds->unlock();
+        if( rc < 0 )
+        {
+            goto error_bootstrap;
+        }
 
         // User created datastores will start from ID 100
         set_update_lastOID(99);
@@ -145,18 +171,21 @@ int DatastorePool::allocate(
         int                 gid,
         const string&       uname,
         const string&       gname,
+        int                 umask,
         DatastoreTemplate * ds_template,
         int *               oid,
         int                 cluster_id,
         const string&       cluster_name,
         string&             error_str)
 {
-    Datastore *     ds;
-    Datastore *     ds_aux = 0;
-    string          name;
-    ostringstream   oss;
+    Datastore * ds;
+    Datastore * ds_aux = 0;
 
-    ds = new Datastore(uid, gid, uname, gname,
+    string name;
+
+    ostringstream oss;
+
+    ds = new Datastore(uid, gid, uname, gname, umask,
             ds_template, cluster_id, cluster_name);
 
     // -------------------------------------------------------------------------
@@ -165,16 +194,11 @@ int DatastorePool::allocate(
 
     ds->get_template_attribute("NAME", name);
 
-    if ( name.empty() )
+    if ( !PoolObjectSQL::name_is_valid(name, error_str) )
     {
         goto error_name;
     }
 
-    if ( name.length() > 128 )
-    {
-        goto error_name_length;
-    }
-
     ds_aux = get(name,false);
 
     if( ds_aux != 0 )
@@ -184,25 +208,27 @@ int DatastorePool::allocate(
 
     *oid = PoolSQL::allocate(ds, error_str);
 
+    if ( *oid != -1 )
+    {
+        Nebula& nd        = Nebula::instance();
+        ImageManager * im = nd.get_imagem();
+
+        if (im != 0 ) //Do not monitor during bootstrap
+        {
+            im->monitor_datastore(*oid);
+        }
+    }
+
     return *oid;
 
-error_name:
-    oss << "NAME cannot be empty.";
-    goto error_common;
-
-error_name_length:
-    oss << "NAME is too long; max length is 128 chars.";
-    goto error_common;
-
 error_duplicated:
     oss << "NAME is already taken by DATASTORE " << ds_aux->get_oid() << ".";
-
-error_common:
-    delete ds;
-
-    *oid = -1;
     error_str = oss.str();
 
+error_name:
+    delete ds;
+    *oid = -1;
+
     return *oid;
 }
 
@@ -215,14 +241,6 @@ int DatastorePool::drop(PoolObjectSQL * objsql, string& error_msg)
 
     int rc;
 
-    // Return error if the datastore is a default one.
-    if( datastore->get_oid() < 100 )
-    {
-        error_msg = "System Datastores (ID < 100) cannot be deleted.";
-        NebulaLog::log("DATASTORE", Log::ERROR, error_msg);
-        return -2;
-    }
-
     if( datastore->get_collection_size() > 0 )
     {
         ostringstream oss;
