@@ -113,6 +113,10 @@ void LifeCycleManager::trigger(Actions action, int _vid)
         aname = "MONITOR_DONE";
         break;
 
+    case MONITOR_POWEROFF:
+        aname = "MONITOR_POWEROFF";
+        break;
+
     case PROLOG_SUCCESS:
         aname = "PROLOG_SUCCESS";
         break;
@@ -334,6 +338,10 @@ void LifeCycleManager::do_action(const string &action, void * arg)
     {
         monitor_done_action(vid);
     }
+    else if (action == "MONITOR_POWEROFF")
+    {
+        monitor_poweroff_action(vid);
+    }
     else if (action == "PROLOG_SUCCESS")
     {
         prolog_success_action(vid);
