@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             #
+# Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -30,15 +30,24 @@ class VirtualMachineDriver < OpenNebulaDriver
 
     # Virtual Machine Driver Protocol constants
     ACTION = {
-        :deploy     => "DEPLOY",
-        :shutdown   => "SHUTDOWN",
-        :reboot     => "REBOOT",
-        :cancel     => "CANCEL",
-        :save       => "SAVE",
-        :restore    => "RESTORE",
-        :migrate    => "MIGRATE",
-        :poll       => "POLL",
-        :log        => "LOG"
+        :deploy      => "DEPLOY",
+        :shutdown    => "SHUTDOWN",
+        :reboot      => "REBOOT",
+        :reset       => "RESET",
+        :cancel      => "CANCEL",
+        :save        => "SAVE",
+        :restore     => "RESTORE",
+        :migrate     => "MIGRATE",
+        :poll        => "POLL",
+        :log         => "LOG",
+        :attach_disk => "ATTACHDISK",
+        :detach_disk => "DETACHDISK",
+        :snapshot_create => "SNAPSHOTCREATE",
+        :snapshot_revert => "SNAPSHOTREVERT",
+        :snapshot_delete => "SNAPSHOTDELETE",
+        :cleanup         => "CLEANUP",
+        :attach_nic  => "ATTACHNIC",
+        :detach_nic  => "DETACHNIC"
     }
 
     POLL_ATTRIBUTE = {
@@ -75,14 +84,26 @@ class VirtualMachineDriver < OpenNebulaDriver
 
         @hosts   = Array.new
 
-        register_action(ACTION[:deploy].to_sym,     method("deploy"))
-        register_action(ACTION[:shutdown].to_sym,   method("shutdown"))
-        register_action(ACTION[:reboot].to_sym,     method("reboot"))
-        register_action(ACTION[:cancel].to_sym,     method("cancel"))
-        register_action(ACTION[:save].to_sym,       method("save"))
-        register_action(ACTION[:restore].to_sym,    method("restore"))
-        register_action(ACTION[:migrate].to_sym,    method("migrate"))
-        register_action(ACTION[:poll].to_sym,       method("poll"))
+        register_action(ACTION[:deploy].to_sym,          method("deploy"))
+        register_action(ACTION[:shutdown].to_sym,        method("shutdown"))
+        register_action(ACTION[:reboot].to_sym,          method("reboot"))
+        register_action(ACTION[:reset].to_sym,           method("reset"))
+        register_action(ACTION[:cancel].to_sym,          method("cancel"))
+        register_action(ACTION[:save].to_sym,            method("save"))
+        register_action(ACTION[:restore].to_sym,         method("restore"))
+        register_action(ACTION[:migrate].to_sym,         method("migrate"))
+        register_action(ACTION[:poll].to_sym,            method("poll"))
+        register_action(ACTION[:attach_disk].to_sym,     method("attach_disk"))
+        register_action(ACTION[:detach_disk].to_sym,     method("detach_disk"))
+        register_action(ACTION[:snapshot_create].to_sym,
+                        method("snapshot_create"))
+        register_action(ACTION[:snapshot_revert].to_sym,
+                        method("snapshot_revert"))
+        register_action(ACTION[:snapshot_delete].to_sym,
+                        method("snapshot_delete"))
+        register_action(ACTION[:cleanup].to_sym,         method("cleanup"))
+        register_action(ACTION[:attach_nic].to_sym,  method("attach_nic"))
+        register_action(ACTION[:detach_nic].to_sym,  method("detach_nic"))
     end
 
     # Decodes the encoded XML driver message received from the core
@@ -122,6 +143,11 @@ class VirtualMachineDriver < OpenNebulaDriver
         send_message(ACTION[:reboot],RESULT[:failure],id,error)
     end
 
+    def reset(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:reset],RESULT[:failure],id,error)
+    end
+
     def cancel(id, drv_message)
         error = "Action not implemented by driver #{self.class}"
         send_message(ACTION[:cancel],RESULT[:failure],id,error)
@@ -147,12 +173,52 @@ class VirtualMachineDriver < OpenNebulaDriver
         send_message(ACTION[:poll],RESULT[:failure],id,error)
     end
 
+    def attach_disk(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:attach_disk],RESULT[:failure],id,error)
+    end
+
+    def detach_disk(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:detach_disk],RESULT[:failure],id,error)
+    end
+
+    def attach_nic(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:attach_nic],RESULT[:failure],id,error)
+    end
+
+    def detach_nic(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:detach_nic],RESULT[:failure],id,error)
+    end
+
+    def snapshot_create(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:snapshot_create],RESULT[:failure],id,error)
+    end
+
+    def snapshot_revert(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:snapshot_revert],RESULT[:failure],id,error)
+    end
+
+    def snapshot_delete(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:snapshot_delete],RESULT[:failure],id,error)
+    end
+
+    def cleanup(id, drv_message)
+        error = "Action not implemented by driver #{self.class}"
+        send_message(ACTION[:cleanup],RESULT[:failure],id,error)
+    end
+
 private
     # Interface to handle the pending events from the ActionManager Interface
     def delete_running_action(action_id)
         action=@action_running[action_id]
         if action
-            @hosts.delete(action[:args][HOST_ARG])
+            @hosts.delete(action[:host])
             @action_running.delete(action_id)
         end
     end
@@ -160,14 +226,28 @@ private
     def get_first_runable
         action_index=nil
         @action_queue.each_with_index do |action, index|
-            if action[:args][HOST_ARG]
-                if !@hosts.include?(action[:args][HOST_ARG])
+            if !action.keys.include?(:host)
+                if action[:args].length == 2
+                    begin
+                        xml=decode(action[:args].last)
+                        host=xml.elements['HOST']
+                        action[:host]=host.text if host
+                    rescue
+                        action[:host]=nil
+                    end
+                else
+                    action[:host]=nil
+                end
+            end
+
+            if action.keys.include?(:host) && action[:host]
+                if !@hosts.include?(action[:host])
                     action_index=index
                     break
                 end
            else
-               action_index=index
-               break
+                action_index=index
+                break
            end
         end
 
@@ -184,7 +264,7 @@ private
         end
 
         if action
-            @hosts << action[:args][HOST_ARG] if action[:args][HOST_ARG]
+            @hosts << action[:host] if action[:host]
             @action_queue.delete_at(action_index)
         end
 
