@@ -1,12 +1,12 @@
 /*******************************************************************************
- * Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)
- * 
+ * Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -35,20 +35,23 @@ public class User extends PoolElement{
     private static final String CHGRP           = METHOD_PREFIX + "chgrp";
     private static final String CHAUTH          = METHOD_PREFIX + "chauth";
     private static final String UPDATE          = METHOD_PREFIX + "update";
-    
+    private static final String QUOTA           = METHOD_PREFIX + "quota";
+    private static final String ADDGROUP        = METHOD_PREFIX + "addgroup";
+    private static final String DELGROUP        = METHOD_PREFIX + "delgroup";
+
     /**
      * Creates a new User representation.
-     * 
+     *
      * @param id The user id (uid).
      * @param client XML-RPC Client.
      */
-    public User(int id, Client client) 
+    public User(int id, Client client)
     {
         super(id, client);
     }
 
     /**
-     * @see PoolElement 
+     * @see PoolElement
      */
     protected User(Node xmlElement, Client client)
     {
@@ -62,10 +65,10 @@ public class User extends PoolElement{
 
     /**
      * Allocates a new user in OpenNebula.
-     * 
+     *
      * @param client XML-RPC Client.
      * @param username Username for the new user.
-     * @param password Password for the new user 
+     * @param password Password for the new user
      * @return If successful the message contains
      * the associated id (int uid) generated for this user.
      */
@@ -95,7 +98,7 @@ public class User extends PoolElement{
     }
 
     /** Retrieves the information of the given user.
-     * 
+     *
      * @param client XML-RPC Client.
      * @param id The user id (uid) for the user to
      * retrieve the information from.
@@ -109,9 +112,9 @@ public class User extends PoolElement{
 
     /**
      * Deletes a user from OpenNebula.
-     * 
+     *
      * @param client XML-RPC Client.
-     * @param id The user id (uid) of the target user we want to delete. 
+     * @param id The user id (uid) of the target user we want to delete.
      * @return If an error occurs the error message contains the reason.
      */
     public static OneResponse delete(Client client, int id)
@@ -121,7 +124,7 @@ public class User extends PoolElement{
 
     /**
      * Changes the password for the given user.
-     * 
+     *
      * @param client XML-RPC Client.
      * @param id The user id (uid) of the target user we want to modify.
      * @param password The new password.
@@ -134,7 +137,7 @@ public class User extends PoolElement{
 
     /**
      * Changes the main group of the given user
-     * 
+     *
      * @param client XML-RPC Client.
      * @param id The user id (uid) of the target user we want to modify.
      * @param gid The new group ID.
@@ -145,9 +148,36 @@ public class User extends PoolElement{
         return client.call(CHGRP, id, gid);
     }
 
+    /**
+     * Adds the User to a secondary group
+     *
+     * @param client XML-RPC Client.
+     * @param id The user id (uid) of the target user we want to modify.
+     * @param gid The new group ID.
+     * @return If an error occurs the error message contains the reason.
+     */
+    public static OneResponse addgroup(Client client, int id, int gid)
+    {
+        return client.call(ADDGROUP, id, gid);
+    }
+
+    /**
+     * Removes the User from a secondary group. Fails if the
+     * group is the main one
+     *
+     * @param client XML-RPC Client.
+     * @param id The user id (uid) of the target user we want to modify.
+     * @param gid The group ID.
+     * @return If an error occurs the error message contains the reason.
+     */
+    public static OneResponse delgroup(Client client, int id, int gid)
+    {
+        return client.call(DELGROUP, id, gid);
+    }
+
     /**
      * Changes the auth driver and the password of the given user
-     * 
+     *
      * @param client XML-RPC Client.
      * @param id The user id (uid) of the target user we want to modify.
      * @param auth The new auth driver.
@@ -169,11 +199,26 @@ public class User extends PoolElement{
      * @param client XML-RPC Client.
      * @param id The user id of the target user we want to modify.
      * @param new_template New template contents.
+     * @param append True to append new attributes instead of replace the whole template
      * @return If successful the message contains the user id.
      */
-    public static OneResponse update(Client client, int id, String new_template)
+    public static OneResponse update(Client client, int id, String new_template,
+        boolean append)
     {
-        return client.call(UPDATE, id, new_template);
+        return client.call(UPDATE, id, new_template, append ? 1 : 0);
+    }
+
+    /**
+     * Replaces the user quota template contents.
+     *
+     * @param client XML-RPC Client.
+     * @param id The user id of the target user we want to modify.
+     * @param quota_template New quota template contents.
+     * @return If successful the message contains the user id.
+     */
+    public static OneResponse setQuota(Client client, int id, String quota_template)
+    {
+        return client.call(QUOTA, id, quota_template);
     }
 
     // =================================
@@ -183,7 +228,7 @@ public class User extends PoolElement{
     /**
      * Loads the xml representation of the user.
      * The info is also stored internally.
-     * 
+     *
      * @see User#info(Client, int)
      */
     public OneResponse info()
@@ -196,7 +241,7 @@ public class User extends PoolElement{
 
     /**
      * Deletes the user from OpenNebula.
-     * 
+     *
      * @see User#delete(Client, int)
      */
     public OneResponse delete()
@@ -206,7 +251,7 @@ public class User extends PoolElement{
 
     /**
      * Changes the password for the user.
-     * 
+     *
      * @param password The new password.
      * @return If an error occurs the error message contains the reason.
      */
@@ -217,7 +262,7 @@ public class User extends PoolElement{
 
     /**
      * Changes the main group of the given user
-     * 
+     *
      * @param gid The new group ID.
      * @return If an error occurs the error message contains the reason.
      */
@@ -226,9 +271,32 @@ public class User extends PoolElement{
         return chgrp(client, id, gid);
     }
 
+    /**
+     * Adds the User to a secondary group
+     *
+     * @param gid The new group ID.
+     * @return If an error occurs the error message contains the reason.
+     */
+    public OneResponse addgroup(int gid)
+    {
+        return addgroup(client, id, gid);
+    }
+
+    /**
+     * Removes the User from a secondary group. Fails if the
+     * group is the main one
+     *
+     * @param gid The group ID.
+     * @return If an error occurs the error message contains the reason.
+     */
+    public OneResponse delgroup(int gid)
+    {
+        return delgroup(client, id, gid);
+    }
+
     /**
      * Changes the auth driver and the password of the given user
-     * 
+     *
      * @param auth The new auth driver.
      * @param password The new password. If it is an empty string,
      * the user password is not changed
@@ -241,7 +309,7 @@ public class User extends PoolElement{
 
     /**
      * Changes the auth driver of the given user
-     * 
+     *
      * @param auth The new auth driver.
      * @return If an error occurs the error message contains the reason.
      */
@@ -258,7 +326,30 @@ public class User extends PoolElement{
      */
     public OneResponse update(String new_template)
     {
-        return update(client, id, new_template);
+        return update(new_template, false);
+    }
+
+    /**
+     * Replaces the user template contents.
+     *
+     * @param new_template New template contents.
+     * @param append True to append new attributes instead of replace the whole template
+     * @return If successful the message contains the user id.
+     */
+    public OneResponse update(String new_template, boolean append)
+    {
+        return update(client, id, new_template, append);
+    }
+
+    /**
+     * Replaces the user quota template contents.
+     *
+     * @param quota_template New quota template contents.
+     * @return If successful the message contains the user id.
+     */
+    public OneResponse setQuota(String quota_template)
+    {
+        return setQuota(client, id, quota_template);
     }
 
     // =================================
@@ -267,7 +358,7 @@ public class User extends PoolElement{
 
     /**
      * Returns true if the user is enabled.
-     * 
+     *
      * @return True if the user is enabled.
      */
     public boolean isEnabled()
