@@ -695,9 +695,10 @@ void VirtualMachineDeploy::request_execute(xmlrpc_c::paramList const& paramList,
     // Get information about the system DS to use (tm_mad)
     // ------------------------------------------------------------------------
 
-    if (is_public_cloud)
-    {
-        ds_id = -1;
+    if (is_public_cloud) // Set ds_id to -1 and tm_mad empty(). This is used by
+    {                    // by VirtualMachine::get_host_is_cloud()
+        ds_id  = -1;
+        tm_mad = "";
     }
     else
     {
@@ -775,10 +776,6 @@ void VirtualMachineDeploy::request_execute(xmlrpc_c::paramList const& paramList,
         }
     }
 
-
-
-
-
     // ------------------------------------------------------------------------
     // Add a new history record and deploy the VM
     // ------------------------------------------------------------------------
@@ -1029,7 +1026,6 @@ void VirtualMachineSaveDisk::request_execute(xmlrpc_c::paramList const& paramLis
 
     ImagePool *     ipool  = nd.get_ipool();
     DatastorePool * dspool = nd.get_dspool();
-    UserPool *      upool  = nd.get_upool();
     VMTemplatePool* tpool  = nd.get_tpool();
 
     int    id          = xmlrpc_c::value_int(paramList.getInt(1));
@@ -1061,24 +1057,6 @@ void VirtualMachineSaveDisk::request_execute(xmlrpc_c::paramList const& paramLis
     string target;
     string dev_prefix;
 
-    // -------------------------------------------------------------------------
-    // Get user's umask
-    // -------------------------------------------------------------------------
-    User * user = upool->get(att.uid, true);
-
-    if ( user == 0 )
-    {
-        failure_response(NO_EXISTS,
-                get_error(object_name(PoolObjectSQL::USER), att.uid),
-                att);
-
-        return;
-    }
-
-    int umask = user->get_umask();
-
-    user->unlock();
-
     // -------------------------------------------------------------------------
     // Prepare and check the VM/DISK to be saved_as
     // -------------------------------------------------------------------------
@@ -1310,7 +1288,7 @@ void VirtualMachineSaveDisk::request_execute(xmlrpc_c::paramList const& paramLis
                              att.gid,
                              att.uname,
                              att.gname,
-                             umask,
+                             att.umask,
                              itemplate,
                              ds_id,
                              ds_name,
@@ -1423,7 +1401,7 @@ void VirtualMachineSaveDisk::request_execute(xmlrpc_c::paramList const& paramLis
 
     //Allocate the template
 
-    rc = tpool->allocate(att.uid, att.gid, att.uname, att.gname, umask,
+    rc = tpool->allocate(att.uid, att.gid, att.uname, att.gname, att.umask,
                 tmpl, &ntid, error_str);
 
     if (rc < 0)
