@@ -34,7 +34,7 @@ module OpenNebulaJSON
 
             self.allocate(template)
        end
-       
+
        def perform_action(template_json)
             action_hash = parse_json(template_json, 'action')
             if OpenNebula.is_error?(action_hash)
@@ -46,10 +46,10 @@ module OpenNebulaJSON
                  when "unpublish"   then self.unpublish
                  when "update"      then self.update(action_hash['params'])
                  when "chown"       then self.chown(action_hash['params'])
-                 when "chmod"       then self.chmod_octet(action_hash['params'])
+                 when "chmod"       then self.chmod_json(action_hash['params'])
                  when "instantiate" then self.instantiate(action_hash['params'])
                  when "clone"       then self.clone(action_hash['params'])
-                 when "rename"      then self.rename(action_hash['params'])                    
+                 when "rename"      then self.rename(action_hash['params'])
                  else
                      error_msg = "#{action_hash['perform']} action not " <<
                          " available for this resource"
@@ -72,16 +72,28 @@ module OpenNebulaJSON
             super(params['owner_id'].to_i,params['group_id'].to_i)
         end
 
-        def chmod_octet(params=Hash.new)
-            super(params['octet'])
+        def chmod_json(params=Hash.new)
+            if params['octet']
+                self.chmod_octet(params['octet'])
+            else
+                self.chmod((params['owner_u']||-1),
+                    (params['owner_m']||-1),
+                    (params['owner_a']||-1),
+                    (params['group_u']||-1),
+                    (params['group_m']||-1),
+                    (params['group_a']||-1),
+                    (params['other_u']||-1),
+                    (params['other_m']||-1),
+                    (params['other_a']||-1))
+            end
         end
 
         def instantiate(params=Hash.new)
             if params['template']
                 template = template_to_str(params['template'])
-                super(params['vm_name'], false, template)
+                super(params['vm_name'], params['hold'], template)
             else
-                super(params['vm_name'])
+                super(params['vm_name'], params['hold'])
             end
         end
 
