@@ -368,6 +368,30 @@ class SunstoneServer < CloudServer
         return [200, {:monitoring => result}.to_json]
     end
 
+    def get_vm_accounting(options)
+        pool = VirtualMachinePool.new(@client)
+
+        filter_flag = options[:userfilter] ? options[:userfilter].to_i : VirtualMachinePool::INFO_ALL
+        start_time  = options[:start_time] ? options[:start_time].to_i : -1
+        end_time    = options[:end_time]   ? options[:end_time].to_i : -1
+
+        acct_options = {
+            :start_time => start_time,
+            :end_time   => end_time,
+            :group      => options[:group]
+        }
+
+        rc = pool.accounting(filter_flag, acct_options)
+
+        if OpenNebula.is_error?(rc)
+            error = Error.new(rc.message)
+            return [500, error.to_json]
+        end
+
+        return [200, rc.to_json]
+    end
+
+
     private
 
     ############################################################################
