@@ -46,6 +46,7 @@ var create_datastore_tmpl =
               <option value="fs_lvm">' + tr("FS LVM") + '</option>\
               <option value="ceph">' + tr("Ceph") + '</option>\
               <option value="gluster">' + tr("Gluster") + '</option>\
+              <option value="dev">' + tr("Devices") + '</option>\
               <option value="custom">' + tr("Custom") + '</option>\
             </select>\
           </div>\
@@ -79,6 +80,7 @@ var create_datastore_tmpl =
                   <option value="lvm">' + tr("LVM") + '</option>\
                   <option value="vmfs">' + tr("VMFS") + '</option>\
                   <option value="ceph">' + tr("Ceph") + '</option>\
+                  <option value="dev">' + tr("Devices") + '</option>\
                   <option value="custom">' + tr("Custom") + '</option>\
                 </select>\
                 <div>\
@@ -96,6 +98,7 @@ var create_datastore_tmpl =
                   <option value="fs_lvm">' + tr("FS LVM") + '</option>\
                   <option value="vmfs">' + tr("VMFS") + '</option>\
                   <option value="ceph">' + tr("Ceph") + '</option>\
+                  <option value="dev">' + tr("Devices") + '</option>\
                   <option value="custom">' + tr("Custom") + '</option>\
                 </select>\
                 <div>\
@@ -415,26 +418,45 @@ var datastore_actions = {
             var ds = params.data.id;
 
             if (cluster == -1){
-                //get cluster name
-                var current_cluster = getValue(ds,
-                                               1,
-                                               6,
-                                               dataTable_datastores);
-                //get cluster id
-                current_cluster = getValue(current_cluster,
-                                           2,
-                                           1,
-                                           dataTable_clusters);
-                if (!current_cluster) return;
-                Sunstone.runAction("Cluster.deldatastore",current_cluster,ds)
+                OpenNebula.Datastore.show({
+                    data : {
+                        id: ds
+                    },
+                    success: function (request, ds_info){
+                        var current_cluster = ds_info.DATASTORE.CLUSTER_ID;
+
+                        if(current_cluster != -1){
+                            OpenNebula.Cluster.deldatastore({
+                                data: {
+                                    id: current_cluster,
+                                    extra_param: ds
+                                },
+                                success: function(){
+                                    OpenNebula.Helper.clear_cache("DATASTORE");
+                                    Sunstone.runAction('Datastore.show',ds);
+                                },
+                                error: onError
+                            });
+                        } else {
+                            OpenNebula.Helper.clear_cache("DATASTORE");
+                            Sunstone.runAction('Datastore.show',ds);
+                        }
+                    },
+                    error: onError
+                });
+            } else {
+                OpenNebula.Cluster.adddatastore({
+                    data: {
+                        id: cluster,
+                        extra_param: ds
+                    },
+                    success: function(){
+                        OpenNebula.Helper.clear_cache("DATASTORE");
+                        Sunstone.runAction('Datastore.show',ds);
+                    },
+                    error: onError
+                });
             }
-            else
-            {
-                Sunstone.runAction("Cluster.adddatastore",cluster,ds);
-            }
-        },
-        callback: function (req) {
-            Sunstone.runAction("Datastore.show",req.request.data[0][0]);
         },
         elements: datastoreElements
     },
@@ -846,6 +868,9 @@ function setupCreateDatastoreDialog(){
           case 'gluster':
             select_gluster();
             break;
+          case 'dev':
+            select_devices();
+            break;
           case 'custom':
             select_custom();
             break;
@@ -1006,6 +1031,11 @@ function select_filesystem(){
     });
     $('select#disk_type').val('file');
     $('select#disk_type').attr('disabled', 'disabled');
+    $('input#safe_dirs').removeAttr('disabled');
+    $('select#disk_type').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
 }
 
 function select_vmware_vmfs(){
@@ -1018,6 +1048,10 @@ function select_vmware_vmfs(){
     $('select#tm_mad').attr('disabled', 'disabled');
     $('select#disk_type').val('file');
     $('select#disk_type').attr('disabled', 'disabled');
+    $('input#safe_dirs').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
 }
 
 function select_ceph(){
@@ -1033,6 +1067,10 @@ function select_ceph(){
     $('label[for="ceph_secret"],input#ceph_secret').parent().fadeIn();
     $('select#disk_type').val('RBD');
     $('select#disk_type').attr('disabled', 'disabled');
+    $('input#safe_dirs').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
 }
 
 function select_block_lvm(){
@@ -1046,6 +1084,10 @@ function select_block_lvm(){
     $('label[for="vg_name"],input#vg_name').fadeIn();
     $('select#disk_type').val('block');
     $('select#disk_type').attr('disabled', 'disabled');
+    $('input#safe_dirs').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
 }
 
 function select_fs_lvm(){
@@ -1057,6 +1099,10 @@ function select_fs_lvm(){
     $('input[name=ds_type]').attr('disabled', 'disabled');
     $('select#disk_type').val('block');
     $('select#disk_type').attr('disabled', 'disabled');
+    $('input#safe_dirs').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
 }
 
 function select_gluster(){
@@ -1078,12 +1124,36 @@ function select_gluster(){
     $('select#disk_type').attr('disabled', 'disabled');
     $('label[for="gluster_host"],input#gluster_host').parent().fadeIn();
     $('label[for="gluster_volume"],input#gluster_volume').parent().fadeIn();
+    $('input#safe_dirs').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
+}
+
+function select_devices(){
+    $('select#ds_mad').val('dev');
+    $('select#ds_mad').attr('disabled', 'disabled');
+    $('select#tm_mad').val('dev');
+    $('select#tm_mad').attr('disabled', 'disabled');
+    $('input#image_ds_type').attr('checked', 'true');
+    $('input[name=ds_type]').attr('disabled', 'disabled');
+    $('select#disk_type').val('block');
+    $('select#disk_type').attr('disabled', 'disabled');
+    $('input#safe_dirs').attr('disabled', 'disabled');
+    $('input#base_path').attr('disabled', 'disabled');
+    $('input#limit_mb').attr('disabled', 'disabled');
+    $('input#restricted_dirs').attr('disabled', 'disabled');
 }
 
 function select_custom(){
     hide_all($create_datastore_dialog);
     $('select#ds_mad').val('fs');
     $('select#tm_mad').val('shared');
+    $('input#safe_dirs').removeAttr('disabled');
+    $('select#disk_type').removeAttr('disabled');
+    $('input#base_path').removeAttr('disabled');
+    $('input#limit_mb').removeAttr('disabled');
+    $('input#restricted_dirs').removeAttr('disabled');
 }
 
 function popUpCreateDatastoreDialog(){
