@@ -67,7 +67,7 @@ function create_group_tmpl(dialog_name){
         <div class="large-12 columns">\
           <p class="subheader">'
             +tr("Allow users in this group to use the following Sunstone views")+
-            '&emsp;<span class="tip">'+tr("Views available to the group users. The default is set in sunstone-views.yaml")+'</span>\
+            '&emsp;<span class="tip">'+tr("Views available to the group users")+'</span>\
           </p>\
         </div>\
       </div>\
@@ -76,6 +76,19 @@ function create_group_tmpl(dialog_name){
             insert_views(dialog_name)
         +'</div>\
       </div>\
+      <div class="row">\
+        <div class="large-12 columns">\
+          <p class="subheader">'
+            +tr("Set the default Sunstone view")+
+            '&emsp;<span class="tip">'+tr("Default view for the group users. If it is unset, the default is set in sunstone-views.yaml")+'</span>\
+          </p>\
+        </div>\
+      </div>\
+      <div class="row">\
+        <div class="large-12 columns">'+
+            insert_views_default(dialog_name)
+        +'</div>\
+      </div>\
     </div>\
     <div id="resource_providers" class="content">\
         <div class="row">\
@@ -107,45 +120,54 @@ function create_group_tmpl(dialog_name){
       </div>\
     </div>\
     <div id="resource_creation" class="content">\
-        <div class="row">\
-          <div class="large-12 columns">\
-            <p class="subheader">'
-              +tr("Allow users in this group to create the following resources")+
-              '&emsp;<span class="tip">'+tr("This will create new ACL Rules to define which virtual resources this group's users will be able to create. You can set different resources for the administrator group, and decide if the administrators will be allowed to create new users.")+'</span>\
-            </p>\
-          </div>\
+      <div class="row">\
+        <div class="large-12 columns">\
+          <label>\
+            <input type="checkbox" id="shared_resources" name="shared_resources" value="YES" />\
+            '+tr("Allow users to view the VMs and Services of other users in the same group")+'\
+            <span class="tip">'+tr("An ACL Rule will be created to give users in this group access to all the resources in the same group.")+'</span>\
+          </label>\
         </div>\
-        <div class="row">\
-          <div class="large-12 columns">\
-            <table class="dataTable" style="table-layout:fixed">\
-              <thead><tr>\
-                <th/>\
-                <th>'+tr("VMs")+'</th>\
-                <th>'+tr("VNets")+'</th>\
-                <th>'+tr("Images")+'</th>\
-                <th>'+tr("Templates")+'</th>\
-                <th>'+tr("Documents")+'<span class="tip">'+tr("Documents are a special tool used for general purposes, mainly by OneFlow. If you want to enable users of this group to use service composition via OneFlow, let it checked.")+'</span></th>\
-              </tr></thead>\
-              <tbody>\
-                <tr>\
-                  <th>'+tr("Users")+'</th>\
-                  <td><input type="checkbox" id="group_res_vm" name="group_res_vm" class="resource_cb" value="VM"></input></td>\
-                  <td><input type="checkbox" id="group_res_net" name="group_res_net" class="resource_cb" value="NET"></input></td>\
-                  <td><input type="checkbox" id="group_res_image" name="group_res_image" class="resource_cb" value="IMAGE"></input></td>\
-                  <td><input type="checkbox" id="group_res_template" name="group_res_template" class="resource_cb" value="TEMPLATE"></input></td>\
-                  <td><input type="checkbox" id="group_res_document" name="group_res_document" class="resource_cb" value="DOCUMENT"></input></td>\
-                  <td/>\
-                </tr>\
-                <tr>\
-                  <th>'+tr("Admins")+'</th>\
-                  <td><input type="checkbox" id="group_admin_res_vm" name="group_admin_res_vm" class="resource_cb" value="VM"></input></td>\
-                  <td><input type="checkbox" id="group_admin_res_net" name="group_admin_res_net" class="resource_cb" value="NET"></input></td>\
-                  <td><input type="checkbox" id="group_admin_res_image" name="group_admin_res_image" class="resource_cb" value="IMAGE"></input></td>\
-                  <td><input type="checkbox" id="group_admin_res_template" name="group_admin_res_template" class="resource_cb" value="TEMPLATE"></input></td>\
-                  <td><input type="checkbox" id="group_admin_res_document" name="group_admin_res_document" class="resource_cb" value="DOCUMENT"></input></td>\
-                </tr>\
-              </tbody>\
-            </table>\
+      </div>\
+      <div class="row">\
+        <div class="large-12 columns">\
+          <p class="subheader">'
+            +tr("Allow users in this group to create the following resources")+
+            '&emsp;<span class="tip">'+tr("This will create new ACL Rules to define which virtual resources this group's users will be able to create. You can set different resources for the administrator group, and decide if the administrators will be allowed to create new users.")+'</span>\
+          </p>\
+        </div>\
+      </div>\
+      <div class="row">\
+        <div class="large-12 columns">\
+          <table class="dataTable" style="table-layout:fixed">\
+            <thead><tr>\
+              <th/>\
+              <th>'+tr("VMs")+'</th>\
+              <th>'+tr("VNets")+'</th>\
+              <th>'+tr("Images")+'</th>\
+              <th>'+tr("Templates")+'</th>\
+              <th>'+tr("Documents")+'<span class="tip">'+tr("Documents are a special tool used for general purposes, mainly by OneFlow. If you want to enable users of this group to use service composition via OneFlow, let it checked.")+'</span></th>\
+            </tr></thead>\
+            <tbody>\
+              <tr>\
+                <th>'+tr("Users")+'</th>\
+                <td><input type="checkbox" id="group_res_vm" name="group_res_vm" class="resource_cb" value="VM"></input></td>\
+                <td><input type="checkbox" id="group_res_net" name="group_res_net" class="resource_cb" value="NET"></input></td>\
+                <td><input type="checkbox" id="group_res_image" name="group_res_image" class="resource_cb" value="IMAGE"></input></td>\
+                <td><input type="checkbox" id="group_res_template" name="group_res_template" class="resource_cb" value="TEMPLATE"></input></td>\
+                <td><input type="checkbox" id="group_res_document" name="group_res_document" class="resource_cb" value="DOCUMENT"></input></td>\
+                <td/>\
+              </tr>\
+              <tr>\
+                <th>'+tr("Admins")+'</th>\
+                <td><input type="checkbox" id="group_admin_res_vm" name="group_admin_res_vm" class="resource_cb" value="VM"></input></td>\
+                <td><input type="checkbox" id="group_admin_res_net" name="group_admin_res_net" class="resource_cb" value="NET"></input></td>\
+                <td><input type="checkbox" id="group_admin_res_image" name="group_admin_res_image" class="resource_cb" value="IMAGE"></input></td>\
+                <td><input type="checkbox" id="group_admin_res_template" name="group_admin_res_template" class="resource_cb" value="TEMPLATE"></input></td>\
+                <td><input type="checkbox" id="group_admin_res_document" name="group_admin_res_document" class="resource_cb" value="DOCUMENT"></input></td>\
+              </tr>\
+            </tbody>\
+          </table>\
         </div>\
       </div>\
     </div>\
@@ -162,22 +184,25 @@ function create_group_tmpl(dialog_name){
 </div>';
 }
 
-var group_quotas_tmpl = '<div class="row" class="subheader">\
-  <div class="large-12 columns">\
-    <h3 id="create_group_quotas_header">'+tr("Update Quota")+'</h3>\
-  </div>\
-</div>\
-<div class="reveal-body">\
-<form id="group_quotas_form" action="">'+
-  quotas_tmpl +
-  '<div class="reveal-footer">\
-    <div class="form_buttons">\
-        <button class="button radius right success" id="create_user_submit" type="submit" value="Group.set_quota">'+tr("Apply changes")+'</button>\
+function group_quotas_tmpl(){
+    return '<div class="row" class="subheader">\
+      <div class="large-12 columns">\
+        <h3 id="create_group_quotas_header">'+tr("Update Quota")+'</h3>\
+      </div>\
     </div>\
-  </div>\
-  <a class="close-reveal-modal">&#215;</a>\
-</form>\
-</div>';
+    <div class="reveal-body">\
+    <form id="group_quotas_form" action="">'+
+      quotas_tmpl() +
+      '<div class="reveal-footer">\
+        <div class="form_buttons">\
+            <button class="button radius right success" id="create_user_submit" \
+            type="submit" value="Group.set_quota">'+tr("Apply changes")+'</button>\
+        </div>\
+      </div>\
+      <a class="close-reveal-modal">&#215;</a>\
+    </form>\
+    </div>';
+}
 
 
 var group_actions = {
@@ -273,11 +298,11 @@ var group_actions = {
         type: "single",
         call: OpenNebula.Group.show,
         callback: function (request,response) {
-            var parsed = parseQuotas(response.GROUP,quotaListItem);
-            $('.current_quotas table tbody',$group_quotas_dialog).append(parsed.VM);
-            $('.current_quotas table tbody',$group_quotas_dialog).append(parsed.DATASTORE);
-            $('.current_quotas table tbody',$group_quotas_dialog).append(parsed.IMAGE);
-            $('.current_quotas table tbody',$group_quotas_dialog).append(parsed.NETWORK);
+            populateQuotasDialog(
+                response.GROUP,
+                default_group_quotas,
+                "#group_quotas_dialog",
+                $group_quotas_dialog);
         },
         error: onError
     },
@@ -439,8 +464,8 @@ Sunstone.addMainTab('groups-tab',groups_tab);
 Sunstone.addInfoPanel("group_info_panel",group_info_panel);
 
 function insert_views(dialog_name){
-  views_checks_str = ""
-  var views_array = config['available_views'];
+  var views_checks_str = "";
+  var views_array = config['all_views'];
   for (var i = 0; i < views_array.length; i++)
   {
     var checked = views_array[i] == 'cloud' ? "checked" : "";
@@ -454,6 +479,20 @@ function insert_views(dialog_name){
   return views_checks_str;
 }
 
+function insert_views_default(dialog_name){
+  var views_checks_str = "";
+  var views_array = config['all_views'];
+  for (var i = 0; i < views_array.length; i++)
+  {
+    views_checks_str = views_checks_str +
+             '<input type="radio" name="group_default_view_'+dialog_name+'" id="group_default_view_'+dialog_name+'_'+views_array[i]+
+                '" value="'+views_array[i]+'"/>' +
+             '<label for="group_default_view_'+dialog_name+'_'+views_array[i]+'">'+views_array[i]+
+             '</label>'
+  }
+  return views_checks_str;
+}
+
 function groupElements(){
     return getSelectedNodes(dataTable_groups);
 }
@@ -491,6 +530,12 @@ function groupElementArray(group_json){
             group.VM_QUOTA.VM.CPU_USED,
             group.VM_QUOTA.VM.CPU,
             default_group_quotas.VM_QUOTA.VM.CPU);
+    } else {
+
+        var vms = quotaBar(0,0,null);
+        var memory = quotaBarMB(0,0,null);
+        var cpu = quotaBarFloat(0,0,null);
+
     }
 
     return [
@@ -643,32 +688,10 @@ function updateGroupInfo(request,group){
       }
 
     var default_group_quotas = Quotas.default_quotas(info.DEFAULT_GROUP_QUOTAS);
-    var vms_quota = Quotas.vms(info, default_group_quotas);
-    var cpu_quota = Quotas.cpu(info, default_group_quotas);
-    var memory_quota = Quotas.memory(info, default_group_quotas);
-    var volatile_size_quota = Quotas.volatile_size(info, default_group_quotas);
-    var image_quota = Quotas.image(info, default_group_quotas);
-    var network_quota = Quotas.network(info, default_group_quotas);
-    var datastore_quota = Quotas.datastore(info, default_group_quotas);
 
-    var quotas_html;
-    if (vms_quota || cpu_quota || memory_quota || volatile_size_quota || image_quota || network_quota || datastore_quota) {
-      quotas_html = '<div class="large-6 columns">' + vms_quota + '</div>';
-      quotas_html += '<div class="large-6 columns">' + cpu_quota + '</div>';
-      quotas_html += '<div class="large-6 columns">' + memory_quota + '</div>';
-      quotas_html += '<div class="large-6 columns">' + volatile_size_quota+ '</div>';
-      quotas_html += '<br><br>';
-      quotas_html += '<div class="large-6 columns">' + image_quota + '</div>';
-      quotas_html += '<div class="large-6 columns">' + network_quota + '</div>';
-      quotas_html += '<br><br>';
-      quotas_html += '<div class="large-12 columns">' + datastore_quota + '</div>';
-    } else {
-      quotas_html = '<div class="row">\
-              <div class="large-12 columns">\
-                <p class="subheader">'+tr("No quotas defined")+'</p>\
-              </div>\
-            </div>'
-    }
+    var quotas_html = initQuotasPanel(info, default_group_quotas,
+        "#group_info_panel",
+        Config.isTabActionEnabled("groups-tab", "Group.quotas_dialog"));
 
     var quotas_tab = {
         title : tr("Quotas"),
@@ -703,9 +726,16 @@ function updateGroupInfo(request,group){
         </div>'
     };
 
+    var accounting_tab = {
+        title: tr("Accounting"),
+        icon: "fa-bar-chart-o",
+        content: '<div id="group_accounting"></div>'
+    };
+
     Sunstone.updateInfoPanelTab("group_info_panel","group_info_tab",info_tab);
     Sunstone.updateInfoPanelTab("group_info_panel","group_quotas_tab",quotas_tab);
     Sunstone.updateInfoPanelTab("group_info_panel","group_providers_tab",providers_tab);
+    Sunstone.updateInfoPanelTab("group_info_panel","group_accouning_tab",accounting_tab);
     Sunstone.popUpInfoPanel("group_info_panel", 'groups-tab');
 
     $("#add_rp_button", $("#group_info_panel")).click(function(){
@@ -715,6 +745,16 @@ function updateGroupInfo(request,group){
 
         return false;
     });
+
+    accountingGraphs(
+        $("#group_accounting","#group_info_panel"),
+        {   fixed_group: info.ID,
+            init_group_by: "user" });
+
+    setupQuotasPanel(info,
+        "#group_info_panel",
+        Config.isTabActionEnabled("groups-tab", "Group.quotas_dialog"),
+        "Group");
 }
 
 function setup_group_resource_tab_content(zone_id, zone_section, str_zone_tab_id, str_datatable_id, selected_group_clusters, group) {
@@ -1108,6 +1148,10 @@ function setupCreateGroupDialog(){
 
         group_json['group']['resources'] = resources;
 
+        if ( $('#shared_resources', this).prop('checked') ){
+            group_json['group']['shared_resources'] = "VM+DOCUMENT";
+        }
+
         if (user_json){
             resources = "";
             separator = "";
@@ -1126,6 +1170,10 @@ function setupCreateGroupDialog(){
             group_json['group']['views'].push($(this).val());
         });
 
+        var default_view = $('[id^="group_default_view"]:checked', dialog).val();
+        if (default_view != undefined){
+            group_json['group']['default_view'] = default_view;
+        }
 
         Sunstone.runAction("Group.create",group_json);
         return false;
@@ -1334,16 +1382,27 @@ function popUpUpdateGroupDialog(group, dialog)
 
 // Add groups quotas dialog and calls common setup() in sunstone utils.
 function setupGroupQuotasDialog(){
-    dialogs_context.append('<div title="'+tr("Group quotas")+'" id="group_quotas_dialog"></div>');
+    dialogs_context.append('<div id="group_quotas_dialog"></div>');
     $group_quotas_dialog = $('#group_quotas_dialog',dialogs_context);
     var dialog = $group_quotas_dialog;
-    dialog.html(group_quotas_tmpl);
+    dialog.html(group_quotas_tmpl());
 
     setupQuotasDialog(dialog);
 }
 
 function popUpGroupQuotasDialog(){
-    popUpQuotasDialog($group_quotas_dialog, 'Group', groupElements())
+    var tab = dataTable_groups.parents(".tab");
+    if (Sunstone.rightInfoVisible(tab)) {
+        $('a[href="#group_quotas_tab"]', tab).click();
+        $('#edit_quotas_button', tab).click();
+    } else {
+        popUpQuotasDialog(
+            $group_quotas_dialog,
+            'Group',
+            groupElements(),
+            default_group_quotas,
+            "#group_quotas_dialog");
+    }
 }
 
 $(document).ready(function(){
