@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2012, OpenNebula Project Leads (OpenNebula.org)             #
+# Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -36,42 +36,33 @@ describe 'Host tests NOKOGIRI' do
     it "should get empty host_pool information" do
         get '/host'
 
+        last_response.body.should eql(File.read(FIXTURES_PATH + '/host/empty.json'))
         last_response.status.should eql(200)
 
-        json_response = JSON.parse(last_response.body)
-        json_response['HOST_POOL'].empty?.should eql(true)
+        #json_response = JSON.parse(last_response.body)
+        #json_response['HOST_POOL'].empty?.should eql(true)
     end
 
     it "should create a first host" do
         post '/host', @host0_s
 
+        last_response.body.should eql(File.read(FIXTURES_PATH + '/host/host0.json'))
         last_response.status.should eql(201)
-
-        json_response = JSON.parse(last_response.body)
-        json_response['HOST']['ID'].should eql("0")
     end
 
     it "should create a second host" do
         post '/host', @host1_s
 
+        last_response.body.should eql(File.read(FIXTURES_PATH + '/host/host1.json'))
         last_response.status.should eql(201)
-
-        json_response = JSON.parse(last_response.body)
-        json_response['HOST']['ID'].should eql("1")
     end
 
     it "should get host 0 information" do
         url = '/host/0'
         get url
 
+        last_response.body.should eql(File.read(FIXTURES_PATH + '/host/host0.json'))
         last_response.status.should eql(200)
-
-        json_response = JSON.parse(last_response.body)
-        json_response['HOST']['NAME'].should eql(@host0_h['host']['name'])
-        json_response['HOST']['IM_MAD'].should eql(@host0_h['host']['im_mad'])
-        json_response['HOST']['VM_MAD'].should eql(@host0_h['host']['vm_mad'])
-        json_response['HOST']['TM_MAD'].should eql(@host0_h['host']['tm_mad'])
-        json_response['HOST']['STATE'].should eql("0")
     end
 
     it "should disable host 0" do
@@ -112,36 +103,15 @@ describe 'Host tests NOKOGIRI' do
         url = '/host/1'
         get url
 
+        last_response.body.should eql(File.read(FIXTURES_PATH + '/host/host1.json'))
         last_response.status.should eql(200)
-
-        json_response = JSON.parse(last_response.body)
-        json_response['HOST']['NAME'].should eql(@host1_h['host']['name'])
-        json_response['HOST']['IM_MAD'].should eql(@host1_h['host']['im_mad'])
-        json_response['HOST']['VM_MAD'].should eql(@host1_h['host']['vm_mad'])
-        json_response['HOST']['TM_MAD'].should eql(@host1_h['host']['tm_mad'])
-        json_response['HOST']['STATE'].should eql("0")
     end
 
     it "should get host_pool information" do
         get '/host'
 
+        last_response.body.should eql(File.read(FIXTURES_PATH + '/host/host_pool.json'))
         last_response.status.should eql(200)
-
-        json_response = JSON.parse(last_response.body)
-        json_response['HOST_POOL']['HOST'].size.should eql(2)
-        json_response['HOST_POOL']['HOST'].each do |host|
-            if host['ID'] == '0'
-                host['NAME'].should eql(@host0_h['host']['name'])
-                host['IM_MAD'].should eql(@host0_h['host']['im_mad'])
-                host['VM_MAD'].should eql(@host0_h['host']['vm_mad'])
-                host['TM_MAD'].should eql(@host0_h['host']['tm_mad'])
-            elsif host['ID'] == '1'
-                host['NAME'].should eql(@host1_h['host']['name'])
-                host['IM_MAD'].should eql(@host1_h['host']['im_mad'])
-                host['VM_MAD'].should eql(@host1_h['host']['vm_mad'])
-                host['TM_MAD'].should eql(@host1_h['host']['tm_mad'])
-            end
-        end
     end
 
     it "should try to get host 3 information and check the error, because " <<
