@@ -135,3 +135,68 @@ void VirtualMachineTemplate::remove_all_except_restricted()
         set(*res_it);
     }
 }
+
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+int VirtualMachineTemplate::replace_disk_image(int target_id, const string&
+    target_name, const string& target_uname, const string& new_name,
+    const string& new_uname)
+{
+    int num_disks;
+    int tmp_id;
+
+    string tmp_name;
+    string tmp_uname;
+
+    vector<Attribute  *> disks;
+    VectorAttribute *    disk = 0;
+
+    num_disks = get("DISK", disks);
+
+    for(int i=0; i<num_disks; i++)
+    {
+        disk = dynamic_cast<VectorAttribute * >(disks[i]);
+
+        if ( disk == 0 )
+        {
+            continue;
+        }
+
+        if (disk->vector_value("IMAGE_ID", tmp_id) == 0) //DISK has IMAGE_ID
+        {
+            if (tmp_id == target_id)
+            {
+                break;
+            }
+        }
+        else //IMAGE and IMAGE_UNAME
+        {
+            tmp_name  = disk->vector_value("IMAGE");
+            tmp_uname = disk->vector_value("IMAGE_UNAME");
+
+            bool uname = tmp_uname.empty() || tmp_uname == target_uname;
+
+            if ( tmp_name == target_name && uname )
+            {
+                break;
+            }
+        }
+
+        disk = 0;
+    }
+
+    if ( disk == 0 )
+    {
+        return -1;
+    }
+
+    disk->remove("IMAGE_ID");
+
+    disk->replace("IMAGE", new_name);
+
+    disk->replace("IMAGE_UNAME", new_uname);
+
+    return 0;
+}
