@@ -222,6 +222,10 @@ class EC2Driver
             'secret_access_key' => @region['secret_access_key'],
             'region'            => @region['region_name'])
 
+        if (proxy_uri = public_cloud_ec2_conf['proxy_uri'])
+            AWS.config(:proxy_uri => proxy_uri)
+        end
+
         @ec2 = AWS.ec2
     end
 
@@ -400,10 +404,8 @@ private
             if all_ec2_elements.size == 1
                 ec2 = all_ec2_elements[0]
             else
-                STDERR.puts(
-                    "Cannot find EC2 element in deployment file "<<
-                    "#{local_dfile} or couldn't find any EC2 site matching "<<
-                    "one of the template.")
+                STDERR.puts("Cannot find EC2 element in deployment file or no" \
+                    "EC2 site matching in the template.")
                 exit(-1)
             end
         end
